<?php

$LANG = array(
    'organization' => 'Organisation',
    'name' => 'Namn',
    'website' => 'Hemsida',
    'work_phone' => 'Telefon',
    'address' => 'Adress',
    'address1' => 'Adress 1',
    'address2' => 'Adress 2',
    'city' => 'Ort',
    'state' => 'Landskap',
    'postal_code' => 'Postnummer',
    'country_id' => 'Land',
    'contacts' => 'Kontakter',
    'first_name' => 'Förnamn',
    'last_name' => 'Efternamn',
    'phone' => 'Telefon',
    'email' => 'E-post',
    'additional_info' => 'Mer info',
    'payment_terms' => 'Betalningsvillkor',
    'currency_id' => 'Valuta',
    'size_id' => 'Storlek',
    'industry_id' => 'Branch',
    'private_notes' => 'Privata anteckningar',
    'invoice' => 'Faktura',
    'client' => 'Kund',
    'invoice_date' => 'Fakturadatum',
    'due_date' => 'Sista betalningsdatum',
    'invoice_number' => 'Fakturanummer',
    'invoice_number_short' => 'Faktura #',
    'po_number' => 'Referensnummer',
    'po_number_short' => 'Referens #',
    'frequency_id' => 'Hur ofta',
    'discount' => 'Rabatt',
    'taxes' => 'Moms',
    'tax' => 'Moms',
    'item' => 'Artikel',
    'description' => 'Beskrivning',
    'unit_cost' => 'Enhetspris',
    'quantity' => 'Antal',
    'line_total' => 'Summa',
    'subtotal' => 'Delsumma',
    'paid_to_date' => 'Betalt hittills',
    'balance_due' => 'Resterande belopp',
    'invoice_design_id' => 'Utseende',
    'terms' => 'Villkor',
    'your_invoice' => 'Din faktura',
    'remove_contact' => 'Ta bort kontakt',
    'add_contact' => 'Lägg till kontakt',
    'create_new_client' => 'Skapa ny kund',
    'edit_client_details' => 'Ändra kunduppgifter',
    'enable' => 'Tillgänglig',
    'learn_more' => 'Hjälp',
    'manage_rates' => 'Hantera priser',
    'note_to_client' => 'Anteckningar till kund',
    'invoice_terms' => 'Fakturavillkor',
    'save_as_default_terms' => 'Spara som standardvillkor',
    'download_pdf' => 'Ladda ner PDF',
    'pay_now' => 'Betala nu',
    'save_invoice' => 'Spara faktura',
    'clone_invoice' => 'Kopia till faktura',
    'archive_invoice' => 'Arkivera faktura',
    'delete_invoice' => 'Ta bort faktura',
    'email_invoice' => 'E-posta faktura',
    'enter_payment' => 'Ange betalning',
    'tax_rates' => 'Momsnivåer',
    'rate' => 'á-pris',
    'settings' => 'Inställningar',
    'enable_invoice_tax' => 'Slå på <b>moms per faktura</b>',
    'enable_line_item_tax' => 'Slå på <b>moms per rad</b>',
    'dashboard' => 'Översikt',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'Kunder',
    'invoices' => 'Fakturor',
    'payments' => 'Betalningar',
    'credits' => 'Kreditfakturor',
    'history' => 'Historik',
    'search' => 'Sök',
    'sign_up' => 'Registrera dig',
    'guest' => 'Gäst',
    'company_details' => 'Företagsinfo',
    'online_payments' => 'Onlinebetalningar',
    'notifications' => 'Meddelanden',
    'import_export' => 'Importera/Exportera',
    'done' => 'Klar',
    'save' => 'Spara',
    'create' => 'Skapa',
    'upload' => 'Ladda upp',
    'import' => 'Importera',
    'download' => 'Ladda ner',
    'cancel' => 'Avbryt',
    'close' => 'Stäng',
    'provide_email' => 'Ange en giltig e-postadress',
    'powered_by' => 'Drivs av',
    'no_items' => 'Inga artiklar',
    'recurring_invoices' => 'Återkommande fakturor',
    'recurring_help' => '<p>Skicka automatiskt fakturor till kund varje vecka, månad, kvartal eller årsvis.</p>
    <p>Använd :MONTH, :QUARTER eller :YEAR för dynamiskt datum. Enkla formler fungerar också, t.ex. :MONTH-1</p>
    <p>Exempel på dynamiska fakturavariabler::</p>
    <ul>
    <li>"Gym medlemskap för månaden :MONTH" >> "Gym medlemskap för månaden Juli"</li>
    <li>":YEAR+1 årlig prenumeration" >> "2015 årlig prenumeration"</li>
    <li>"Underhåll för :QUARTER+1" >> "Underhåll för Q2"</li>
    </ul>',
    'recurring_quotes' => 'Återkommande offerter',
    'in_total_revenue' => 'i totala intäkter',
    'billed_client' => 'fakturerad kund',
    'billed_clients' => 'fakturerade kunder',
    'active_client' => 'aktiv kund',
    'active_clients' => 'aktiva kunder',
    'invoices_past_due' => 'Försenade fakturor',
    'upcoming_invoices' => 'Kommande fakturor',
    'average_invoice' => 'Genomsnittlig faktura',
    'archive' => 'Arkiv',
    'delete' => 'Ta bort',
    'archive_client' => 'Arkivera kund',
    'delete_client' => 'Radera kund',
    'archive_payment' => 'Arkivera betalning',
    'delete_payment' => 'Ta bort betalning',
    'archive_credit' => 'Arkiverade kreditfakturor',
    'delete_credit' => 'Ta bort kreditfaktura',
    'show_archived_deleted' => 'Visa arkiverade/borttagna',
    'filter' => 'Filter',
    'new_client' => 'Ny kund',
    'new_invoice' => 'Ny faktura',
    'new_payment' => 'Ny betalning',
    'new_credit' => 'Ange Kredit',
    'contact' => 'Kontakt',
    'date_created' => 'Skapat datum',
    'last_login' => 'Senast inloggad',
    'balance' => 'Balans',
    'action' => 'Hantera',
    'status' => 'Status',
    'invoice_total' => 'Totalsumma',
    'frequency' => 'Frekvens',
    'range' => 'Range',
    'start_date' => 'Startdatum',
    'end_date' => 'Slutdatum',
    'transaction_reference' => 'Transaktion referens',
    'method' => 'Metod',
    'payment_amount' => 'Betald summa',
    'payment_date' => 'Betalningsdatum',
    'credit_amount' => 'Kreditsumma',
    'credit_balance' => 'Kreditbalans',
    'credit_date' => 'Kreditdatum',
    'empty_table' => 'Ingen data tillgänglig',
    'select' => 'Välj',
    'edit_client' => 'Redigera kund',
    'edit_invoice' => 'Redigera faktura',
    'create_invoice' => 'Skapa faktura',
    'enter_credit' => 'Ange kredit',
    'last_logged_in' => 'Senast inloggad',
    'details' => 'Detaljer',
    'standing' => 'Summering',
    'credit' => 'Kredit',
    'activity' => 'Händelse',
    'date' => 'Datum',
    'message' => 'Meddelande',
    'adjustment' => 'Justering',
    'are_you_sure' => 'Är du säker?',
    'payment_type_id' => 'Betalningssätt',
    'amount' => 'Summa',
    'work_email' => 'E-postadress',
    'language_id' => 'Språk',
    'timezone_id' => 'Tidszon',
    'date_format_id' => 'Datumformat',
    'datetime_format_id' => 'Datum-/tidformat',
    'users' => 'Användare',
    'localization' => 'Språkanpassning',
    'remove_logo' => 'Ta bort logotyp',
    'logo_help' => 'Giltiga format: JPEG, GIF och PNG',
    'payment_gateway' => 'Betalningstjänst',
    'gateway_id' => 'Tjänst',
    'email_notifications' => 'E-post Notifieringar',
    'email_sent' => 'Skicka e-post när faktura <b>skickas</b>',
    'email_viewed' => 'Skicka e-post när faktura <b>visas</b>',
    'email_paid' => 'Skicka e-post när faktura <b>betalas</b>',
    'site_updates' => 'Sajt-uppdateringar',
    'custom_messages' => 'Anpassat meddelande',
    'default_email_footer' => 'Ange standard <b>e-post signatur</b>',
    'select_file' => 'Välj fil',
    'first_row_headers' => 'Använd första raden som rubrik',
    'column' => 'Kolumn',
    'sample' => 'Exempel',
    'import_to' => 'Importera till',
    'client_will_create' => 'kund kommer skapas',
    'clients_will_create' => 'kunder kommer skapas',
    'email_settings' => 'E-postinställningar',
    'client_view_styling' => 'Utformning av kund vy',
    'pdf_email_attachment' => 'Bifoga PDF',
    'custom_css' => 'Anpassad CSS',
    'import_clients' => 'Importera kundinformation',
    'csv_file' => 'Välj CSV-fil',
    'export_clients' => 'Exportera kundinformation',
    'created_client' => 'Kund skapad',
    'created_clients' => ':count kund(er) skapade',
    'updated_settings' => 'Inställningar uppdaterade',
    'removed_logo' => 'Logotyp borttagen',
    'sent_message' => 'Meddelandet skickat',
    'invoice_error' => 'Välj kund och rätta till eventuella fel',
    'limit_clients' => 'Du kan max skapa :count kunder',
    'payment_error' => 'Något blev fel när din betalning bearbetades. Var vänlig och försök igen lite senare.',
    'registration_required' => 'Du måste registrera dig för att kunna skicka en faktura som e-post',
    'confirmation_required' => 'Please confirm your email address, :link to resend the confirmation email.',
    'updated_client' => 'Kund uppdaterad',
    'archived_client' => 'Kund arkiverad',
    'archived_clients' => ':count kunder arkiverade',
    'deleted_client' => 'kund borttagen',
    'deleted_clients' => ':count kunder borttagna',
    'updated_invoice' => 'Faktura uppdaterad',
    'created_invoice' => 'Faktura skapad',
    'cloned_invoice' => 'Faktura kopierad',
    'emailed_invoice' => 'Faktura skickad som e-post',
    'and_created_client' => 'och kund skapad',
    'archived_invoice' => 'Faktura arkiverad',
    'archived_invoices' => ':count fakturor arkiverade',
    'deleted_invoice' => 'Faktura borttagen',
    'deleted_invoices' => ':count fakturor borttagna',
    'created_payment' => 'Betalning registrerad',
    'created_payments' => 'Framgångsrikt skapat :count betalning(ar)',
    'archived_payment' => 'Betalning arkiverad',
    'archived_payments' => ':count betalningar arkiverade',
    'deleted_payment' => 'Betalning borttagen',
    'deleted_payments' => ':count betalningar borttagna',
    'applied_payment' => 'Betalning applicerad',
    'created_credit' => 'Kreditfaktura skapad',
    'archived_credit' => 'Kreditfaktura arkiverad',
    'archived_credits' => ':count kreditfakturor arkiverade',
    'deleted_credit' => 'Kreditfaktura borttagen',
    'deleted_credits' => ':count kreditfakturor borttagna',
    'imported_file' => 'Framgångsrikt importerat fil',
    'updated_vendor' => 'Framgångsrikt uppdaterat leverantör',
    'created_vendor' => 'Framgångsrikt skapat leverantör',
    'archived_vendor' => 'Framgångsrikt arkiverat leverantör',
    'archived_vendors' => 'Framgångsrikt arkiverat :count leverantörer',
    'deleted_vendor' => 'Framgångsrikt raderat leverantör',
    'deleted_vendors' => 'Framgångsrikt raderat :count leverantörer',
    'confirmation_subject' => 'Bekräfta ditt Invoice Ninja konto',
    'confirmation_header' => 'Bekräfta ditt konto',
    'confirmation_message' => 'Vänligen klick på länken nedan för att bekräfta ditt konto.',
    'invoice_subject' => 'Ny faktura :number från :account',
    'invoice_message' => 'Klicka på länken nedan för att visa din faktura på :amount.',
    'payment_subject' => 'Betalning mottagen',
    'payment_message' => 'Tack för din betalning på :amount.',
    'email_salutation' => 'Hej :name,',
    'email_signature' => 'Vänliga hälsningar,',
    'email_from' => 'Invoice Ninja teamet',
    'invoice_link_message' => 'För att se din kundfaktura klicka på länken nedan:',
    'notification_invoice_paid_subject' => 'Faktura :invoice är betald av :client',
    'notification_invoice_sent_subject' => 'Faktura :invoice är skickad till :client',
    'notification_invoice_viewed_subject' => 'Faktura :invoice har setts av :client',
    'notification_invoice_paid' => 'En betalning på :amount är gjord av kunden :client för faktura :invoice.',
    'notification_invoice_sent' => 'Följande kund :client har e-postats fakturan :invoice på :amount.',
    'notification_invoice_viewed' => 'Följande kund :client har sett fakturan :invoice på :amount.',
    'reset_password' => 'Du kan återställa ditt lösenord genom att klicka på länken nedan:',
    'secure_payment' => 'Säker betalning',
    'card_number' => 'Kortnummer',
    'expiration_month' => 'Giltig till, månad',
    'expiration_year' => 'Giltig till, år',
    'cvv' => 'CVV',
    'logout' => 'Logga ut',
    'sign_up_to_save' => 'Registrera dig för att spara ditt arbete',
    'agree_to_terms' => 'Jag accepterar :terms',
    'terms_of_service' => 'Villkor för tjänsten',
    'email_taken' => 'E-postadressen är redan registrerad',
    'working' => 'Jobbar',
    'success' => 'Lyckades',
    'success_message' => 'Du har nu registrerat dig. Klicka på länken i ditt bekräftelsemail för att verifiera din e-postadress.',
    'erase_data' => 'Ditt konto är inte registrerat , detta kommer permanent ta bort din information.',
    'password' => 'Lösenord',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Tack för att du väljer Invoice Ninja\'s Pro!<p/>&nbsp;<br/>
          <b>Nästa steg</b><p/>En faktura har skickats till din angivna e-postadress.
          Var vänlig och följ instruktionerna på fakturan för att betala för ett års
          Pro fakturering och få tillgång till alla fantastiska Pro-funktioner.<p/>
          Hittar du inte fakturan? Behöver du support? Vi hjälper dig!
          -- maila oss på contact@invoiceninja.com',
    'unsaved_changes' => 'Du har osparade ändringar',
    'custom_fields' => 'Anpassade fält',
    'company_fields' => 'Företagsfält',
    'client_fields' => 'Kundfält',
    'field_label' => 'Fältrubrik',
    'field_value' => 'Fältvärde',
    'edit' => 'Ändra',
    'set_name' => 'Ange ditt företagsnamn',
    'view_as_recipient' => 'Se som mottagare',
    'product_library' => 'Produktbibliotek',
    'product' => 'Produkt',
    'products' => 'Produkter',
    'fill_products' => 'Auto-ifyll produkter',
    'fill_products_help' => 'Välj en produkt för att automatiskt <b>fylla i beskrivning och pris</b>',
    'update_products' => 'Auto-uppdaterade produkter',
    'update_products_help' => 'Uppdatera en faktura för att automatiskt <b>uppdatera produktbiblioteket</b>',
    'create_product' => 'Lägg till produkt',
    'edit_product' => 'Redigera produkt',
    'archive_product' => 'Arkivera produkt',
    'updated_product' => 'Produkt uppdaterad',
    'created_product' => 'Produkt skapad',
    'archived_product' => 'Produkt arkiverad',
    'pro_plan_custom_fields' => ':link för att slå på anpassade fält genom att uppgradera till Pro',
    'advanced_settings' => 'Avancerade inställningar',
    'pro_plan_advanced_settings' => ':link för att slå på avancerade inställningar genom att uppgradera till Pro',
    'invoice_design' => 'Fakturadesign',
    'specify_colors' => 'Ange färger',
    'specify_colors_label' => 'Välj färger som ska användas på fakturan',
    'chart_builder' => 'Diagrambyggare',
    'ninja_email_footer' => 'Skapad av :site | Skapa. Skicka. Få betalt.',
    'go_pro' => 'Uppgradera till Pro',
    'quote' => 'Offert',
    'quotes' => 'Offerter',
    'quote_number' => 'Offertnummer',
    'quote_number_short' => 'Offert #',
    'quote_date' => 'Offertdatum',
    'quote_total' => 'Offertsumma',
    'your_quote' => 'Din offert',
    'total' => 'Totalsumma',
    'clone' => 'Kopiera',
    'new_quote' => 'Ny offert',
    'create_quote' => 'Skapa offert',
    'edit_quote' => 'Ändra offert',
    'archive_quote' => 'Arkivera offert',
    'delete_quote' => 'Ta bort offert',
    'save_quote' => 'Spara offert',
    'email_quote' => 'E-posta offert',
    'clone_quote' => 'Klona till Offert',
    'convert_to_invoice' => 'Omvandla till faktura',
    'view_invoice' => 'Visa faktura',
    'view_client' => 'Visa kund',
    'view_quote' => 'Visa offert',
    'updated_quote' => 'Offert uppdaterad',
    'created_quote' => 'Offert skapad',
    'cloned_quote' => 'Offert kopierad',
    'emailed_quote' => 'Offert e-postad',
    'archived_quote' => 'Offert arkiverad',
    'archived_quotes' => ':count offerter arkiverade',
    'deleted_quote' => 'Offert borttagen',
    'deleted_quotes' => ':count offerter borttagna',
    'converted_to_invoice' => 'Offert konverterad till faktura',
    'quote_subject' => 'Ny offert :number från :account',
    'quote_message' => 'Klicka på länken nedan för att visa din offert på :amount.',
    'quote_link_message' => 'Klicka på länken nedan för att visa din offert:',
    'notification_quote_sent_subject' => 'Offert :invoice har skickats till :client',
    'notification_quote_viewed_subject' => 'Offert :invoice har setts av :client',
    'notification_quote_sent' => 'Följande kunde :client har e-postats offerten :invoice på :amount.',
    'notification_quote_viewed' => 'Följande kunder :client har sett offerten :invoice på :amount.',
    'session_expired' => 'Din session har avslutats.',
    'invoice_fields' => 'Fakturafält',
    'invoice_options' => 'Fakturainställningar',
    'hide_paid_to_date' => 'Dölj "Betald till"',
    'hide_paid_to_date_help' => 'Visa bara "Betald till"-sektionen på fakturan när en betalning har mottagits.',
    'charge_taxes' => 'Inkludera moms',
    'user_management' => 'Användarhantering',
    'add_user' => 'Lägg till användare',
    'send_invite' => 'Skicka inbjudan',
    'sent_invite' => 'Inbjudan skickad',
    'updated_user' => 'Användare uppdaterad',
    'invitation_message' => 'Du har blivit inbjuden av :invitor. ',
    'register_to_add_user' => 'Registrera dig för att lägga till en användare',
    'user_state' => 'Status',
    'edit_user' => 'Ändra användare',
    'delete_user' => 'Ta bort användare',
    'active' => 'Aktiv',
    'pending' => 'Pågående',
    'deleted_user' => 'Användare borttagen',
    'confirm_email_invoice' => 'Är du säker på att du vill e-posta denna fakturan?',
    'confirm_email_quote' => 'Är du säker på att du vill e-posta denna offerten?',
    'confirm_recurring_email_invoice' => 'Återkommande fakturor är påslaget, är du säker på att du vill e-post denna fakturan?',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'Avsluta konto',
    'cancel_account_message' => 'Varning: Detta kommer permanent ta bort ditt konto, detta går inte att ångra.',
    'go_back' => 'Tillbaka',
    'data_visualizations' => 'Datavisualisering',
    'sample_data' => 'Exempeldata visas',
    'hide' => 'Dölj',
    'new_version_available' => 'En ny version av :releases_link finns tillgänglig. Du kör just nu v:user_version och senaste är v:latest_version',
    'invoice_settings' => 'Fakturainställningar',
    'invoice_number_prefix' => 'Fakturaprefix',
    'invoice_number_counter' => 'Fakturaräknare',
    'quote_number_prefix' => 'Offertprefix',
    'quote_number_counter' => 'Offerträknare',
    'share_invoice_counter' => 'Dela fakturaräknare',
    'invoice_issued_to' => 'Faktura ställd till',
    'invalid_counter' => 'För att undvika nummerkonflikt så bör antingen faktura- eller offertprefix anges',
    'mark_sent' => 'Markera skickad',
    'gateway_help_1' => ':link för att registrera dig på Authorize.net.',
    'gateway_help_2' => ':link för att registrera dig på Authorize.net.',
    'gateway_help_17' => ':link för att hämta din PayPal API-nyckel.',
    'gateway_help_27' => ':link för att registrera dig för 2Checkout.com. För att säkerställa att betalningar spåras :complete_link som den omdirigeringsadressen under Konto> Platshantering i 2Checkout portalen.',
    'gateway_help_60' => ':link för att skapa WePay konto',
    'more_designs' => 'Fler fakturalayouter',
    'more_designs_title' => 'Fler fakturalayouter',
    'more_designs_cloud_header' => 'Uppgrader till Pro för fler fakturalayouter',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Köp',
    'bought_designs' => 'Fler fakturalayouter tillagda',
    'sent' => 'Skickat',
    'vat_number' => 'Momsregistreringsnummer',
    'timesheets' => 'Tidrapporter',
    'payment_title' => 'Ange din fakturaadress och betalkortsinformation',
    'payment_cvv' => '*Detta är den 3-4 siffriga koden på baksidan av ditt kort',
    'payment_footer1' => '*Fakturaadressen måste stämma överens med adressen kopplad till betalkortet.',
    'payment_footer2' => '*Klicka bara en gång på "BETALA NU" - transaktionen kan ta upp till 1 minut att behandla.',
    'id_number' => 'ID-nummer',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'White label licens köpt',
    'white_labeled' => 'White labeled',
    'restore' => 'Återställ',
    'restore_invoice' => 'Återställ faktura',
    'restore_quote' => 'Återställ offert',
    'restore_client' => 'Återställ kund',
    'restore_credit' => 'Återställ kreditfaktura',
    'restore_payment' => 'Återställ betalning',
    'restored_invoice' => 'Faktura återställd',
    'restored_quote' => 'Offert återställd',
    'restored_client' => 'Kund återställd',
    'restored_payment' => 'betalning återställd',
    'restored_credit' => 'Kreditfaktura återställd',
    'reason_for_canceling' => 'Hjälp oss bli bättre genom att berätta varför du lämnar oss.',
    'discount_percent' => 'Procent',
    'discount_amount' => 'Summa',
    'invoice_history' => 'Fakturahistorik',
    'quote_history' => 'Offerthistorik',
    'current_version' => 'Nuvarande version',
    'select_version' => 'Välj version',
    'view_history' => 'Visa historik',
    'edit_payment' => 'Ändra betalning',
    'updated_payment' => 'Betalning uppdaterad',
    'deleted' => 'Ta bort',
    'restore_user' => 'Återställ användare',
    'restored_user' => 'Användare återställd',
    'show_deleted_users' => 'Visa borttagna användare',
    'email_templates' => 'E-post mallar',
    'invoice_email' => 'Faktura e-post',
    'payment_email' => 'Betalnings e-post',
    'quote_email' => 'Offert e-post',
    'reset_all' => 'Återställ allt',
    'approve' => 'Godkänn',
    'token_billing_type_id' => 'Token fakturering',
    'token_billing_help' => 'Lagra betalnings info med WePay, Stripe, Braintree eller GoCardless.',
    'token_billing_1' => 'Avstängd',
    'token_billing_2' => 'Opt-in - Checkbox visas men är inte förvald',
    'token_billing_3' => 'Opt-out - Checkbox visas och är förvald',
    'token_billing_4' => 'alltid',
    'token_billing_checkbox' => 'Spara betalkortsinformation',
    'view_in_gateway' => 'Visa i :gateway',
    'use_card_on_file' => 'Använd kort på fil',
    'edit_payment_details' => 'Ändra betalningsdetaljer',
    'token_billing' => 'Spara kortinformation',
    'token_billing_secure' => 'Data sparas säkert med :link',
    'support' => 'Support',
    'contact_information' => 'Kontaktinformation',
    '256_encryption' => '256-bitars kryptering',
    'amount_due' => 'Belopp att betala',
    'billing_address' => 'Fakturaadress',
    'billing_method' => 'Faktureringsmetod',
    'order_overview' => 'Orderöversikt',
    'match_address' => '*Adressen måste stämma överens med adressen kopplad till betalkortet.',
    'click_once' => '*Klicka bara en gång på "BETALA NU" - transaktionen kan ta upp till 1 minut att behandla.',
    'invoice_footer' => 'Faktura sidfot',
    'save_as_default_footer' => 'Spara som standard sidfot',
    'token_management' => 'Token hantering',
    'tokens' => 'Tokens',
    'add_token' => 'Lägg till token',
    'show_deleted_tokens' => 'Visa borttagna tokens',
    'deleted_token' => 'Token borttagen',
    'created_token' => 'Token skapad',
    'updated_token' => 'Token uppdaterad',
    'edit_token' => 'Ändra token',
    'delete_token' => 'Ta bort token',
    'token' => 'Token',
    'add_gateway' => 'Lägg till gateway',
    'delete_gateway' => 'Ta bort gateway',
    'edit_gateway' => 'Ändra gateway',
    'updated_gateway' => 'Gateway uppdaterad',
    'created_gateway' => 'Gateway skapad',
    'deleted_gateway' => 'Gateway borttagen',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Betalkort',
    'change_password' => 'Ändra lösenord',
    'current_password' => 'Nuvarande lösenord',
    'new_password' => 'Nytt lösenord',
    'confirm_password' => 'Bekräfta lösenord',
    'password_error_incorrect' => 'Nuvarande lösenord är felaktigt.',
    'password_error_invalid' => 'Det nya lösenordet är felaktigt.',
    'updated_password' => 'Lösenord uppdaterat',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Användare och tokens',
    'account_login' => 'Inloggning',
    'recover_password' => 'Återställ ditt lösenord',
    'forgot_password' => 'Glömt ditt lösenord?',
    'email_address' => 'E-postadress',
    'lets_go' => 'Kör på',
    'password_recovery' => 'Återställ lösenord',
    'send_email' => 'Skicka epost',
    'set_password' => 'Ange lösenord',
    'converted' => 'Konvertera',
    'email_approved' => 'Mejla mig när offerten är <b>godkänd</b>',
    'notification_quote_approved_subject' => 'Offert :invoice är godkänd av :client',
    'notification_quote_approved' => 'Följande klient :client godkände Offert :invoice för :amount',
    'resend_confirmation' => 'Skicka om bekräftelse e-post',
    'confirmation_resent' => 'Bekräftelse e-post omskickat',
    'gateway_help_42' => ':link för att registrera dig för BitPay <br/> Notering: Använd en Legacy API-nyckel, inte en API-token.',
    'payment_type_credit_card' => 'Betalkort',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Kunskapsdatabas',
    'partial' => 'delinsättning',
    'partial_remaining' => ':partial av :balance',
    'more_fields' => 'Fler fält',
    'less_fields' => 'Färre fält',
    'client_name' => 'Kundnamn',
    'pdf_settings' => 'PDF Settings',
    'product_settings' => 'Produkt inställningar',
    'auto_wrap' => 'Automatisk Rad Byte',
    'duplicate_post' => 'Varning: föregående sida var inlämnad två gånger. Den andra inlämningen blev ignorerad.',
    'view_documentation' => 'se dokumentation',
    'app_title' => 'Gratis Open-Source online fakturering',
    'app_description' => 'Invoice Ninja är en gratis, öppen programvarulösning för fakturering av kunder. Med Invoice Ninja kan ni lätt skapa och skicka snygga fakturor från vilken teknisk utrustning som helst som har tillgång till internet. Era kunder kan skriva ut era fakturor, ladda ner dem som pdf-filer, och betala online.',
    'rows' => 'rader',
    'www' => 'www',
    'logo' => 'Logotyp',
    'subdomain' => 'Underdomän',
    'provide_name_or_email' => 'Ange ett namn eller epost',
    'charts_and_reports' => 'Listor och rapporter',
    'chart' => 'Lista',
    'report' => 'Rapport',
    'group_by' => 'Gruppera genom',
    'paid' => 'Betald',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Lista',
    'totals' => 'Total',
    'run' => 'Kör',
    'export' => 'Exportera',
    'documentation' => 'Dokumentation',
    'zapier' => 'Zapier',
    'recurring' => 'Återkommande',
    'last_invoice_sent' => 'Senaste fakturan skickad :date',
    'processed_updates' => 'Lyckad genomförd uppdatering',
    'tasks' => 'Uppgifter',
    'new_task' => 'Ny uppgift',
    'start_time' => 'Start-tid',
    'created_task' => 'Framgångsrikt skapad uppgift',
    'updated_task' => 'Lyckad uppdatering av uppgift',
    'edit_task' => 'Redigera uppgift',
    'clone_task' => 'Klona uppgift',
    'archive_task' => 'Arkivera uppgift',
    'restore_task' => 'Återställa uppgift',
    'delete_task' => 'Radera uppgift',
    'stop_task' => 'Avbryt uppgift',
    'time' => 'Tid',
    'start' => 'Start',
    'stop' => 'Stoppa',
    'now' => 'Nu',
    'timer' => 'Timer',
    'manual' => 'Manuell',
    'date_and_time' => 'Datum & Tid',
    'second' => 'Sekund',
    'seconds' => 'Sekunder',
    'minute' => 'Minut',
    'minutes' => 'Minuter',
    'hour' => 'Timme',
    'hours' => 'Timmar',
    'task_details' => 'Uppgift information',
    'duration' => 'Varaktighet',
    'time_log' => 'Tidslogg',
    'end_time' => 'Sluttid',
    'end' => 'Slut',
    'invoiced' => 'Fakturerad',
    'logged' => 'Loggat',
    'running' => 'Körs',
    'task_error_multiple_clients' => 'Uppgiften kan ej tillhöra olika kunder',
    'task_error_running' => 'Avsluta uppgift som körs först',
    'task_error_invoiced' => 'Uppgift har redan blivit fakturerad',
    'restored_task' => 'Framgångsrikt återställd uppgift',
    'archived_task' => 'Framgångsrikt arkiverad uppgift',
    'archived_tasks' => 'Framgångsrikt arkiverade :count uppgifter',
    'deleted_task' => 'Framgångsrikt raderad uppgift',
    'deleted_tasks' => 'Framgångsrikt raderade :count uppgifter',
    'create_task' => 'Skapa uppgift',
    'stopped_task' => 'Framgångsrikt stoppad uppgift',
    'invoice_task' => 'Fakturera uppgift',
    'invoice_labels' => 'Faktura märkning',
    'prefix' => 'Prefix',
    'counter' => 'Räknare',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link för att registrera för Dwolla.',
    'partial_value' => 'Måste vara större än noll och mindre än totalen',
    'more_actions' => 'Fler åtgärder',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Uppgradera Nu!',
    'pro_plan_feature1' => 'Skapa obegränsat antal kunder',
    'pro_plan_feature2' => 'Tillgång till 10 snygga faktura utformningar',
    'pro_plan_feature3' => 'Egna URLer - "dindoman.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Radera "Skapad av Invoice Ninja"',
    'pro_plan_feature5' => 'Fleranvändare tillgång & aktivitet spårning',
    'pro_plan_feature6' => 'Skapa offerter & provisoriska fakturor',
    'pro_plan_feature7' => 'Skräddarsy fakturafält, rubriker och numrering',
    'pro_plan_feature8' => 'Valmöjlighet att bifoga PDF-filer till kunds e-post',
    'resume' => 'Återuppta',
    'break_duration' => 'Mellanrum',
    'edit_details' => 'Redigera uppgifter',
    'work' => 'Arbete',
    'timezone_unset' => 'Vänligen använd :link för att ställa in din tidszon',
    'click_here' => 'klicka här',
    'email_receipt' => 'E-posta kvitto till kunden',
    'created_payment_emailed_client' => 'Skapade framgångsrikt betalning och e-postade kund',
    'add_company' => 'Lägg till företag',
    'untitled' => 'Obetitlad',
    'new_company' => 'Nytt företag',
    'associated_accounts' => 'Framgångsrikt sammankopplade konton',
    'unlinked_account' => 'Framgångsrikt olänkade konton',
    'login' => 'Logga in',
    'or' => 'eller',
    'email_error' => 'Det uppstod ett problem med att skicka e-post',
    'confirm_recurring_timing' => 'Observera: E-post skickas vid timmens början',
    'confirm_recurring_timing_not_sent' => 'Observera: Fakturor skapas vid timmens början.',
    'payment_terms_help' => 'Ställ in standard <b>faktura förfallodatum</b>',
    'unlink_account' => 'Olänka konto',
    'unlink' => 'Olänka',
    'show_address' => 'Visa adress',
    'show_address_help' => 'Kräv kund att meddela faktura-adress ',
    'update_address' => 'Uppdatera adress',
    'update_address_help' => 'Uppdatera kundens adress med tillhandahållna uppgifter',
    'times' => 'Tider',
    'set_now' => 'Satt till nu',
    'dark_mode' => 'Mörkt läge',
    'dark_mode_help' => 'Använd en mörk bakgrund för sidebars',
    'add_to_invoice' => 'Lägg till på faktura :invoice',
    'create_new_invoice' => 'Skapa ny faktura',
    'task_errors' => 'Korrigera överlappande tider',
    'from' => 'Från',
    'to' => 'Till',
    'font_size' => 'Storlek på framsida',
    'primary_color' => 'Primär färg',
    'secondary_color' => 'Sekundär färg',
    'customize_design' => 'Skräddarsy utformning',
    'content' => 'Innehåll',
    'styles' => 'Utformningar',
    'defaults' => 'Förinställningar',
    'margins' => 'Marginaler',
    'header' => 'Rubrik',
    'footer' => 'Sidfot',
    'custom' => 'Utforma',
    'invoice_to' => 'Faktura till',
    'invoice_no' => 'Faktura nr.',
    'quote_no' => 'Offert nr.',
    'recent_payments' => 'Nyligen utförda betalningar',
    'outstanding' => 'Utestående/Obetalt',
    'manage_companies' => 'Hantera företag',
    'total_revenue' => 'Totala intäkter',
    'current_user' => 'Befintlig användare',
    'new_recurring_invoice' => 'Ny återkommande faktura',
    'recurring_invoice' => 'Återkommande faktura',
    'new_recurring_quote' => 'Ny upprepande offert',
    'recurring_quote' => 'Återkommande offert',
    'recurring_too_soon' => 'Det är för tidigt att skapa nästa återkommande faktura, den är schemalagd för :date',
    'created_by_invoice' => 'Skapad av :invoice',
    'primary_user' => 'Primär användare',
    'help' => 'Hjälp',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'Sandlåda',
    'support_forum' => 'Supportforum',
    'invoice_due_date' => 'Förfallodatum',
    'quote_due_date' => 'Giltig till',
    'valid_until' => 'Giltig till',
    'reset_terms' => 'Återställ villkor',
    'reset_footer' => 'Återställ sidfot',
    'invoice_sent' => ':count fakturor skickade',
    'invoices_sent' => ':count fakturor skickade',
    'status_draft' => 'Utkast',
    'status_sent' => 'Skickat',
    'status_viewed' => 'Granskad/Tittad på',
    'status_partial' => 'Del',
    'status_paid' => 'Betald',
    'status_unpaid' => 'Obetald',
    'status_all' => 'Alla',
    'show_line_item_tax' => 'Visa <b>Linje produkt moms i kö</b>',
    'iframe_url' => 'Webbsida',
    'iframe_url_help1' => 'Kopiera följande kod till en sida på din webbplats',
    'iframe_url_help2' => 'Du kan testa utseendet på en faktura genom att klicka "titta som mottagare" ',
    'auto_bill' => 'Auto debitera',
    'military_time' => '24 Timmars tid',
    'last_sent' => 'Senast skickat/skickade',
    'reminder_emails' => 'Påminnelse e-post',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => 'Mallar & Påminnelser',
    'subject' => 'Subject',
    'body' => 'Organisation/Avdelning',
    'first_reminder' => 'Första Påminnelse',
    'second_reminder' => 'Andra Påminnelse',
    'third_reminder' => 'Tredje Påminnelse',
    'num_days_reminder' => 'Dagar efter förfallodatum',
    'reminder_subject' => 'Påminnelse: Faktura :invoice från :account',
    'reset' => 'Återställa',
    'invoice_not_found' => 'Den efterfrågade fakturan är inte tillgänglig',
    'referral_program' => 'Referensprogram',
    'referral_code' => 'Referens URL',
    'last_sent_on' => 'Senast skickat: :date',
    'page_expire' => 'Denna sida kommer att utgå snart, :click_here för att fortsätta arbeta',
    'upcoming_quotes' => 'Kommande Offerter',
    'expired_quotes' => 'Utgångna Offerter',
    'sign_up_using' => 'Registrera dig med hjälp av',
    'invalid_credentials' => 'Dessa uppgifter matchar inte våra register',
    'show_all_options' => 'Visa alla alternativ',
    'user_details' => 'Användaruppgifter',
    'oneclick_login' => 'Kopplat konto',
    'disable' => 'inaktivera',
    'invoice_quote_number' => 'Faktura och Offert Nummer',
    'invoice_charges' => 'Tilläggsavgifter till faktura',
    'notification_invoice_bounced' => 'Det finns ingen möjlighet att leverera :invoice till :contact.',
    'notification_invoice_bounced_subject' => 'Ej möjligt att leverera faktura :invoice',
    'notification_quote_bounced' => 'Ej möjligt att leverera Quote :invoice till :contact.',
    'notification_quote_bounced_subject' => 'Ej möjligt att leverera Quote :invoice',
    'custom_invoice_link' => 'Modiferad Faktura Länk',
    'total_invoiced' => 'Totalt fakturerat',
    'open_balance' => 'Resterande belopp',
    'verify_email' => 'Besök länken i e-post kontobekräftelsen för att verifiera din email adress',
    'basic_settings' => 'Grundläggande inställningar',
    'pro' => 'Pro',
    'gateways' => 'Betalningsgateway',
    'next_send_on' => 'Skicka nästa: :date',
    'no_longer_running' => 'Denna faktura är inte schemalagd att köras',
    'general_settings' => 'Generella inställningar',
    'customize' => 'Skräddarsy',
    'oneclick_login_help' => 'Anslut ett konto att logga in utan lösenord',
    'referral_code_help' => 'Tjäna pengar genom att dela vår app online',
    'enable_with_stripe' => 'Aktivera | Kräv Stripe',
    'tax_settings' => 'Moms inställningar',
    'create_tax_rate' => 'Lägg till momssats/skattenivå',
    'updated_tax_rate' => 'Framgångsrikt uppdaterad momssats',
    'created_tax_rate' => 'Framgångsrikt skapat skattesats ',
    'edit_tax_rate' => 'Redigera skattenivå',
    'archive_tax_rate' => 'Arkivera skattenivå',
    'archived_tax_rate' => 'Framgångsrikt arkiverat skattenivån/momssatsen',
    'default_tax_rate_id' => 'Förinställd skattenivå/momssats',
    'tax_rate' => 'Skattenivå',
    'recurring_hour' => 'Återkommande Timme',
    'pattern' => 'Mönster',
    'pattern_help_title' => 'Mönster Hjälp',
    'pattern_help_1' => 'Skapa anpassade nummer genom att ange ett mönster.',
    'pattern_help_2' => 'Tillgängliga variabler:',
    'pattern_help_3' => 'Till exempel, :example hade konverterats till :value',
    'see_options' => 'Se alternativ',
    'invoice_counter' => 'Faktura räknare',
    'quote_counter' => 'Offert räknare',
    'type' => 'Typ',
    'activity_1' => ':user skapade kund :client',
    'activity_2' => ':user arkiverade kund :client',
    'activity_3' => ':user raderade kund :client',
    'activity_4' => ':user skapade faktura :invoice',
    'activity_5' => ':user uppdaterade faktura :invoice',
    'activity_6' => ':user mailade faktura :invoice för :client till :contact',
    'activity_7' => ':contact visade faktura :invoice för :client',
    'activity_8' => ':user arkiverade faktura :invoice',
    'activity_9' => ':user raderade faktura :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user uppdaterade betalning :payment',
    'activity_12' => ':user arkiverade betalning :payment',
    'activity_13' => ':user tog bort betalning :payment',
    'activity_14' => ':user skickade in :credit kredit',
    'activity_15' => ':user updaterade :credit kredit',
    'activity_16' => ':user arkiverade :credit kredit',
    'activity_17' => ':user tog bort :credit kredit',
    'activity_18' => ':user skapade offert :quote',
    'activity_19' => ':user uppdaterade offert :quote',
    'activity_20' => ':user mailade offert :quote för :client för :contact',
    'activity_21' => ':contact visade offert :quote',
    'activity_22' => ':user arkiverade offert :quote',
    'activity_23' => ':user tog bort offert :quote',
    'activity_24' => ':user återställde offert :quote',
    'activity_25' => ':user återställde Faktura :invoice',
    'activity_26' => ':user återställde klient :client',
    'activity_27' => ':user återställde betalning :payment',
    'activity_28' => ':user återställde :credit kredit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user skapade leverantör :vendor',
    'activity_31' => ':user arkiverade leverantör :vendor',
    'activity_32' => ':user tog bort leverantör :vendor',
    'activity_33' => ':user återställde leverantör :vendor',
    'activity_34' => ':user skapade kostnad :expense',
    'activity_35' => ':user arkiverade kostnad :expense',
    'activity_36' => ':user tog bort kostnad :expense',
    'activity_37' => ':user återställde kostnad :expense',
    'activity_42' => ':user skapade uppgift :task',
    'activity_43' => ':user uppdaterade uppgift :task',
    'activity_44' => ':user arkiverade uppgift :task',
    'activity_45' => ':user tog bort uppgift :task',
    'activity_46' => ':user återställde uppgift :task',
    'activity_47' => ':user uppdaterade kostnad :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Betalning',
    'system' => 'System',
    'signature' => 'E-post Signatur',
    'default_messages' => 'Standardmeddelanden',
    'quote_terms' => 'Offertvillkor',
    'default_quote_terms' => 'Standard Offertvillkor',
    'default_invoice_terms' => 'Ange standard <b>fakturavillkor</b>',
    'default_invoice_footer' => 'Ange som standard <b>faktura sidfot</b>',
    'quote_footer' => 'Offert footer',
    'free' => 'Gratis',
    'quote_is_approved' => 'Godkänd',
    'apply_credit' => 'Tillämpa kredit',
    'system_settings' => 'Systeminställningar',
    'archive_token' => 'Arkivera Token',
    'archived_token' => 'Framgångsrikt arkiverat Token',
    'archive_user' => 'Arkivera Användare',
    'archived_user' => 'Framgångsrikt arkiverat användare',
    'archive_account_gateway' => 'Ta bort Gateway',
    'archived_account_gateway' => 'Framgångsrikt arkiverat gateway',
    'archive_recurring_invoice' => 'Arkivera återkommande faktura',
    'archived_recurring_invoice' => 'Framgångsrikt arkiverat återkommande faktura',
    'delete_recurring_invoice' => 'Ta bort återkommande faktura',
    'deleted_recurring_invoice' => 'Framgångsrikt tagit bort återkommande faktura',
    'restore_recurring_invoice' => 'Återställ återkommande faktura',
    'restored_recurring_invoice' => 'Framgångsrikt återställt återkommande faktura',
    'archive_recurring_quote' => 'Arkivera återkommande offert',
    'archived_recurring_quote' => 'Successfully archived recurring quote',
    'delete_recurring_quote' => 'Ta bort återkommande offert',
    'deleted_recurring_quote' => 'Successfully deleted recurring quote',
    'restore_recurring_quote' => 'Återställ återkommande offert',
    'restored_recurring_quote' => 'Successfully restored recurring quote',
    'archived' => 'Arkiverad',
    'untitled_account' => 'Namnlöst Företag',
    'before' => 'Före',
    'after' => 'Efter',
    'reset_terms_help' => 'Återställ till standard konto villkor',
    'reset_footer_help' => 'Återställ till standard konto footer',
    'export_data' => 'Exportera data',
    'user' => 'Användare',
    'country' => 'Land',
    'include' => 'Inkludera',
    'logo_too_large' => 'Din logotyp är :size, för bättre PDF-prestanda rekommenderar vi en filstorlek på mindre än 200KB',
    'import_freshbooks' => 'Importera från FreshBooks',
    'import_data' => 'Importera Data',
    'source' => 'Källa',
    'csv' => 'CSV',
    'client_file' => 'Klientfil',
    'invoice_file' => 'Fakturafil',
    'task_file' => 'Uppgiftsfil',
    'no_mapper' => 'Ingen giltig mappning för fil',
    'invalid_csv_header' => 'Ogiltig CSV huvud',
    'client_portal' => 'Klient Portal',
    'admin' => 'Admin',
    'disabled' => 'Avstängd',
    'show_archived_users' => 'Visa arkiverade användare',
    'notes' => 'Notis',
    'invoice_will_create' => 'Faktura kommer skapas',
    'invoices_will_create' => 'fakturor kommer skapas',
    'failed_to_import' => 'Följande fält misslyckades att importeras, antingen finns dom redan eller saknar obligatoriska fält.',
    'publishable_key' => 'Publik nyckel',
    'secret_key' => 'Hemlig nyckel',
    'missing_publishable_key' => 'Sätt din Stripe publicerbara nyckel för förbättrad utcheckningsprocess.',
    'email_design' => 'E-post design',
    'due_by' => 'Förfallodag :date',
    'enable_email_markup' => 'Aktivera märkning',
    'enable_email_markup_help' => 'Gör det enklare för dina klienter att betala genom att lägga till schema.org märkning till dina e-post.',
    'template_help_title' => 'Mallhjälp',
    'template_help_1' => 'Tillgängliga variabler:',
    'email_design_id' => 'E-post stil',
    'email_design_help' => 'Få din e-post att se mer professionella ut med HTML layout.',
    'plain' => 'Vanlig',
    'light' => 'Ljus',
    'dark' => 'Mörk',
    'industry_help' => 'Används för att ge jämförelser mot genomsnitten för företag med liknande storlek och bransch.',
    'subdomain_help' => 'Ställ in subdomänen eller visa fakturorna på din egen hemsida',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Specifiera ett prefix eller anpassat mönster för att dynamiskt sätta fakturanummer.',
    'quote_number_help' => 'Specifiera ett prefix eller använd ett anpassat mönster för att dynamiskt sätta offert nummer.',
    'custom_client_fields_helps' => 'Lägg till ett fält när en kund skapas och visa rubriken samt värdet om du önskar på PDF. ',
    'custom_account_fields_helps' => 'Lägg till en etikett och värde för företagsinformationsdelen av PDF.',
    'custom_invoice_fields_helps' => 'Lägg till ett fält när en faktura skapas och visa rubriken samt värdet om du önskar på PDF. ',
    'custom_invoice_charges_helps' => 'Lägg till ett fält när du skapar en faktura och inkludera avgiften i fakturans delkostnader.',
    'token_expired' => 'Valideringstoken har gått ut. Snälla försök igen.',
    'invoice_link' => 'Faktura länk',
    'button_confirmation_message' => 'Klicka för att bekräfta din e-post adress.',
    'confirm' => 'Bekräfta',
    'email_preferences' => 'E-post inställningar',
    'created_invoices' => 'Framgångsrikt skapat :count faktur(a/or)',
    'next_invoice_number' => 'Nästa fakturanummer är :number.',
    'next_quote_number' => 'Nästa offert nummer är :number',
    'days_before' => 'dagar före',
    'days_after' => 'dagar efter',
    'field_due_date' => 'förfallodatum',
    'field_invoice_date' => 'faktura datum',
    'schedule' => 'Schema',
    'email_designs' => 'E-post designs',
    'assigned_when_sent' => 'Genereras vid skapande',
    'white_label_purchase_link' => 'Köp en white label licens',
    'expense' => 'Utgift',
    'expenses' => 'Utgifter',
    'new_expense' => 'Ny Kostnad',
    'enter_expense' => 'Skriv in Kostnad',
    'vendors' => 'Leverantörer',
    'new_vendor' => 'Ny leverantör',
    'payment_terms_net' => 'Netto',
    'vendor' => 'Leverantör',
    'edit_vendor' => 'Ändra leverantör',
    'archive_vendor' => 'Arkivera leverantör',
    'delete_vendor' => 'Ta bort leverantör',
    'view_vendor' => 'Se Leverantör',
    'deleted_expense' => 'Framgångsrikt tagit bort kostnad',
    'archived_expense' => 'Framgångsrikt arkiverat kostnad',
    'deleted_expenses' => 'Framgångsrikt tagit bort kostnader',
    'archived_expenses' => 'Framgångsrikt arkiverat kostnader',
    'expense_amount' => 'Kostnadsbelopp',
    'expense_balance' => 'Kostnads balans',
    'expense_date' => 'Kostnads datum',
    'expense_should_be_invoiced' => 'Ska denna kostnad faktureras?',
    'public_notes' => 'Publika noteringar',
    'invoice_amount' => 'Faktura belopp',
    'exchange_rate' => 'Växlingskurs',
    'yes' => 'Ja',
    'no' => 'Nej',
    'should_be_invoiced' => 'Ska detta faktureras',
    'view_expense' => 'Visa kostnad # :expense',
    'edit_expense' => 'Redigera kostnad',
    'archive_expense' => 'Arkivera kostnad',
    'delete_expense' => 'Ta bort kostnad',
    'view_expense_num' => 'Kostnad # :expense',
    'updated_expense' => 'Framgångsrikt uppdaterat kostnad',
    'created_expense' => 'Framgångsrikt skapat kostnad',
    'enter_expense' => 'Skriv in Kostnad',
    'view' => 'Visa',
    'restore_expense' => 'Återställ kostnad',
    'invoice_expense' => 'Faktura kostnad',
    'expense_error_multiple_clients' => 'Kostnaderna kan inte tillhöra olika klienter',
    'expense_error_invoiced' => 'Kostnad har redan blivit fakturerad',
    'convert_currency' => 'Konvertera valuta',
    'num_days' => 'Antal dagar',
    'create_payment_term' => 'Skapa betalningsvillkor',
    'edit_payment_terms' => 'Editera betalningsvillkor',
    'edit_payment_term' => 'Editera betalningsvillkor',
    'archive_payment_term' => 'Arkivera betalningsvillkor',
    'recurring_due_dates' => 'Återkommande faktura förfallodatum',
    'recurring_due_date_help' => '<P> Sätter automatiskt ett förfallodatum för fakturan. </ P> 
<p> Fakturor på en månadsvis eller årlig cykel, på eller före den dag de skapas kommer att bero på nästa månad. Fakturor som förfaller på den 29: e eller 30: e månader som inte har den dagen kommer att betalas den sista dagen i månaden. </ P> 
 <p> fakturor på en veckocykeln beror på dagen för veckan de skapas kommer att bero på nästa vecka </ p> 
 <p> till exempel:. </ p> 
 <ul> 
 <li> Idag är den 15: e, är förfallodag första i månaden. Förfallodagen skulle sannolikt vara den första nästa månad. </ Li> 
 <li> Idag är den 15: e, då är förfallodagen den sista dagen i månaden. Förfallodagen blir den sista dagen av denna månad.
 </ li> 
 <li> Idag är den 15: e, är förfallodagen den 15: e dagen i månaden. Förfallodagen är den 15: e dagen av <strong> Nästa </ strong> månad.
</ li> 
 <li> Är idagg en fredag, är förfallodagen den 1: a fredag efter. Förfallodagen kommer att vara nästa fredag, inte idag. 
 </ li> 
 </ ul>',
    'due' => 'förfallen',
    'next_due_on' => 'Förfallen nästa :',
    'use_client_terms' => 'Använd klient villkor',
    'day_of_month' => ':ordinal dag i månaden',
    'last_day_of_month' => 'Sista dagen i månaden',
    'day_of_week_after' => ':ordinal :day efter',
    'sunday' => 'Söndag',
    'monday' => 'Måndag',
    'tuesday' => 'Tisdag',
    'wednesday' => 'Onsdag',
    'thursday' => 'Torsdag',
    'friday' => 'Fredag',
    'saturday' => 'Lördag',
    'header_font_id' => 'Header Font',
    'body_font_id' => 'Body Font',
    'color_font_help' => 'Notering: Den primära färgen och fonterna används också i klient portalen och anpassade e-post designerna.',
    'live_preview' => 'Live förhandsgranskning',
    'invalid_mail_config' => 'Oförmögen att skicka mejl, vänligen kontrollera att e-post inställningarna är korrekta.',
    'invoice_message_button' => 'För att visa din faktura på :amount, klicka på knappen nedan.',
    'quote_message_button' => 'För att visa din offert på :amount, klicka på knappen nedan.',
    'payment_message_button' => 'Tack för din betalning på :amount.',
    'payment_type_direct_debit' => 'Direktbetalning',
    'bank_accounts' => 'Betalkort och Banker',
    'add_bank_account' => 'Lägg till Bankkonto',
    'setup_account' => 'Sätt upp konto',
    'import_expenses' => 'Importera kostnader',
    'bank_id' => 'Bank',
    'integration_type' => 'Integreringstyp',
    'updated_bank_account' => 'Framgångsrikt uppdaterat bankkonto',
    'edit_bank_account' => 'Editera Bankkonto',
    'archive_bank_account' => 'Arkivera Bankkonto',
    'archived_bank_account' => 'Framgångsrikt arkiverat bankkonto',
    'created_bank_account' => 'Framgångsrikt skapat bankkonto',
    'validate_bank_account' => 'Validera Bankkonto',
    'bank_password_help' => 'Notera: ditt lösenord överförs säkert och lagras aldrig på våra servrar.',
    'bank_password_warning' => 'Varning: ditt lösenord kan överföras i klartext, överväg att aktivera HTTPS.',
    'username' => 'Användarnamn',
    'account_number' => 'Kontonummer',
    'account_name' => 'Kontonamn',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Godkänd',
    'quote_settings' => 'Offert inställningar.',
    'auto_convert_quote' => 'Auto Konvertera',
    'auto_convert_quote_help' => 'Konvertera automatiskt en offert till en faktura när den godkänts av en klient.',
    'validate' => 'Validera',
    'info' => 'Info',
    'imported_expenses' => 'Framgångsrikt skapat :count_vendors leverantör(er) och :count_expenses kostnad(er)',
    'iframe_url_help3' => 'Notera: Om du planerar att acceptera kreditkort uppgifter, rekommenderas vi att ni aktivera HTTPs på er sida.',
    'expense_error_multiple_currencies' => 'Kostnaderna kan inte ha olika valutor.',
    'expense_error_mismatch_currencies' => 'Klientens valuta matchar inte valutan på kostnaden.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Header/Footer',
    'first_page' => 'Första sidan',
    'all_pages' => 'Alla sidor',
    'last_page' => 'Sista sidan',
    'all_pages_header' => 'Visa Header på',
    'all_pages_footer' => 'Visa Footer på',
    'invoice_currency' => 'Faktura valuta',
    'enable_https' => 'Vi rekommenderar starkt att ni använder HTTPS för att acceptera kreditkorts detaljer på nätet.',
    'quote_issued_to' => 'Offert utfärdad till',
    'show_currency_code' => 'Valuta kod',
    'free_year_message' => 'Ditt konto har uppgraderats till pro planen 1 år utan extra kostnad.',
    'trial_message' => 'Ditt konto kommer att få två veckor pröva-på-tid av på pro plan.',
    'trial_footer' => 'Din fria pro plans testperiod varar :count ytterligare dagar, :link för att uppgradera nu.',
    'trial_footer_last_day' => 'Detta är sista dagen av din fria pro plans testperiod, :link för att uppgradera nu.',
    'trial_call_to_action' => 'Starta test period',
    'trial_success' => 'Lyckades aktivera två veckors gratis testversion för Pro nivå',
    'overdue' => 'Försenat',


    'white_label_text' => 'Köp ETT ÅR white label licens för $:price för att ta bort bort Invoice Ninja referens från faktura och klient portal.',
    'user_email_footer' => 'För att anpassa dina e-post notifieringar gå till :link',
    'reset_password_footer' => 'Om du inte begärt en återställning av ditt lösenord så var snäll och e-posta vår support: :email',
    'limit_users' => 'Ledsen, men du får skapa max :limit användare',
    'more_designs_self_host_header' => 'Få ytterliggare 6 fakturalayouter för bara $:price',
    'old_browser' => 'Vänligen använd en :link',
    'newer_browser' => 'nyare webbläsare',
    'white_label_custom_css' => ':link för $:price aktiverar du din egen stil och hjälper till att stödja vårt projekt.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link för att ta bort Invoice Ninja-logotypen genom att uppgradera till Pro nivå',
    'pro_plan_remove_logo_link' => 'Klicka här',
    'invitation_status_sent' => 'Skickat',
    'invitation_status_opened' => 'Öppnat',
    'invitation_status_viewed' => 'Visad',
    'email_error_inactive_client' => 'E-post kan inte skickas till inaktiva klienter',
    'email_error_inactive_contact' => 'E-post kan inte skickas till inaktiva kontakter',
    'email_error_inactive_invoice' => 'E-post kan inte skickas till inaktiva fakturor',
    'email_error_inactive_proposal' => 'Mail kan inte skickas till inaktiva förslag',
    'email_error_user_unregistered' => 'Vänligen registrera ditt konto för att skicka e-post',
    'email_error_user_unconfirmed' => 'Vänligen verifiera ditt konto för att skicka e-post',
    'email_error_invalid_contact_email' => 'Ogiltig kontakt e-post',

    'navigation' => 'Navigation',
    'list_invoices' => 'Lista Fakturor',
    'list_clients' => 'Lista Klienter',
    'list_quotes' => 'Lista Offerter',
    'list_tasks' => 'Lista uppgifter',
    'list_expenses' => 'Lista utgifter',
    'list_recurring_invoices' => 'Lista återkommande fakturor',
    'list_payments' => 'Lista betalningar',
    'list_credits' => 'Lista krediter',
    'tax_name' => 'Skattenamn',
    'report_settings' => 'Rapport inställingar',
    'search_hotkey' => 'genväg är /',

    'new_user' => 'Ny användare',
    'new_product' => 'Ny produkt',
    'new_tax_rate' => 'Ny skatte nivå',
    'invoiced_amount' => 'Fakturerad summa',
    'invoice_item_fields' => 'Fakturerat varu belopp',
    'custom_invoice_item_fields_help' => 'Lägg till ett fält när fakturan skapas och visa namn samt värde på PDF´n',
    'recurring_invoice_number' => 'Återkommande nummer',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Lösenordsskydda fakturor',
    'enable_portal_password_help' => 'Tillåter dig att sätta ett lösenord för varje kontakt. Om ett lösenord är valt kommer kontakten vara tvungen att skriva in lösenordet innan den kan se fakturan.',
    'send_portal_password' => 'Skapa automatiskt',
    'send_portal_password_help' => 'Om inget lösenord är satt, kommer ett bli genererat och skickat med första fakturan.',

    'expired' => 'Utgått',
    'invalid_card_number' => 'Kreditkortsnumret är inte giltigt',
    'invalid_expiry' => 'Utgångsdatumen är inte giltig.',
    'invalid_cvv' => 'CVV koden är inte giltig.',
    'cost' => 'Kostnad',
    'create_invoice_for_sample' => 'Notis: skapa din första faktura för en förhandsvisning här',

    // User Permissions
    'owner' => 'Ägare',
    'administrator' => 'Administratör',
    'administrator_help' => 'Tillåt användare att hantera användare, ändra inställningar och ändra alla värden',
    'user_create_all' => 'Skrapa klienter, fakturor etc.',
    'user_view_all' => 'Visa alla klienter, fakturor etc.',
    'user_edit_all' => 'Ändra alla klienter, fakturor etc.',
    'gateway_help_20' => ':link för att aktivera Sage Pay.',
    'gateway_help_21' => ':link för att aktivera Sage Pay.',
    'partial_due' => 'Delvis försenad',
    'restore_vendor' => 'Återställ leverantör',
    'restored_vendor' => 'Lyckades återställa leverantör',
    'restored_expense' => 'Lyckades återställa utgifter',
    'permissions' => 'Behörigheter',
    'create_all_help' => 'Tillåt användare att skapa eller ändra värden',
    'view_all_help' => 'Tillåt användare att se värden de inte skapat',
    'edit_all_help' => 'Tillåt användare att ändra värden de inte skapat',
    'view_payment' => 'Se betalning',

    'january' => 'Januari',
    'february' => 'Februari',
    'march' => 'Mars',
    'april' => 'April',
    'may' => 'Maj',
    'june' => 'Juni',
    'july' => 'Juli',
    'august' => 'Augusti',
    'september' => 'September',
    'october' => 'Oktober',
    'november' => 'November',
    'december' => 'December',

    // Documents
    'documents_header' => 'Dokument:',
    'email_documents_header' => 'Dokument:',
    'email_documents_example_1' => 'Widgets kvitto.pdf',
    'email_documents_example_2' => 'Slutgiltig levererbar.zip',
    'quote_documents' => 'Offert dokument',
    'invoice_documents' => 'Faktura dokument',
    'expense_documents' => 'Utgifts dokument',
    'invoice_embed_documents' => 'Bädda in dokument',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Bifoga dokument',
    'ubl_email_attachment' => 'Bifoga UBL',
    'download_documents' => 'Ladda ner dokument (:size)',
    'documents_from_expenses' => 'Från utgifter:',
    'dropzone_default_message' => 'Släpp filer eller klicka för att ladda upp',
    'dropzone_default_message_disabled' => 'Uppladdningar avstängt',
    'dropzone_fallback_message' => 'Din webbläsare stödjer inte drag o släpp uppladdningar.',
    'dropzone_fallback_text' => 'Vänligen använd det bakåtkompatibla formuläret nedan för att ladda upp filer som på den gamla goda tiden.',
    'dropzone_file_too_big' => 'Filen är för stor ({{filesize}}MiB). Max filestorlek: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Du kan inte ladda upp filer av denna typen',
    'dropzone_response_error' => 'Servern svarade med {{statusCode}} kod.',
    'dropzone_cancel_upload' => 'Avbryt uppladdning',
    'dropzone_cancel_upload_confirmation' => 'Är du säker du vill avbryta denna uppladdningen?',
    'dropzone_remove_file' => 'Ta bort fil',
    'documents' => 'Dokument',
    'document_date' => 'Dokumentdatum',
    'document_size' => 'Storlek',

    'enable_client_portal' => 'Klient portal',
    'enable_client_portal_help' => 'Visa/dölj klient portalen.',
    'enable_client_portal_dashboard' => 'Översikt',
    'enable_client_portal_dashboard_help' => 'Visa/dölj översikten i klient portalen.',

    // Plans
    'account_management' => 'Kontohantering',
    'plan_status' => 'Nivå status',

    'plan_upgrade' => 'Uppgradera',
    'plan_change' => 'Byta nivå',
    'pending_change_to' => 'Ändras till',
    'plan_changes_to' => ':plan den :date',
    'plan_term_changes_to' => ':plan (:term) den :date',
    'cancel_plan_change' => 'Avbryt ändringar',
    'plan' => 'Nivå',
    'expires' => 'Utgår',
    'renews' => 'Förnyelse',
    'plan_expired' => ':plan nivån löpt ut',
    'trial_expired' => ':plan nivåns testperiod avslutad',
    'never' => 'Aldrig',
    'plan_free' => 'Gratis',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Egen hostad (White label)',
    'plan_free_self_hosted' => 'Egen hostad (Gratis)',
    'plan_trial' => 'Testperiod',
    'plan_term' => 'Period',
    'plan_term_monthly' => 'Månadsvis',
    'plan_term_yearly' => 'Årligen',
    'plan_term_month' => 'Månad',
    'plan_term_year' => 'År',
    'plan_price_monthly' => '$:price/Månad',
    'plan_price_yearly' => '$:price/År',
    'updated_plan' => 'Uppdatera nivå inställningar',
    'plan_paid' => 'Period startad',
    'plan_started' => 'Nivå startad',
    'plan_expires' => 'Nivå utgår',

    'white_label_button' => 'White label',

    'pro_plan_year_description' => 'Ett års registering på Invoice Ninja Pro nivå.',
    'pro_plan_month_description' => 'En månads registering på Invoice Ninja Pro nivå.',
    'enterprise_plan_product' => 'Enterprise nivå',
    'enterprise_plan_year_description' => 'Ett års registering på Invoice Ninja Enterprise nivån.',
    'enterprise_plan_month_description' => 'En månads registering på Invoice Ninja Enterprise nivån.',
    'plan_credit_product' => 'Kredit',
    'plan_credit_description' => 'Kredit för oanvänd tid',
    'plan_pending_monthly' => 'Bytar till månadsvis den :date',
    'plan_refunded' => 'En återbetalning har blivit gjord.',

    'live_preview' => 'Live förhandsgranskning',
    'page_size' => 'Sidstorlek',
    'live_preview_disabled' => 'Live förhandsgranskning har stängts av för att stödja fonten',
    'invoice_number_padding' => 'Stoppning',
    'preview' => 'Förhandsgranska',
    'list_vendors' => 'Lista leverantörer',
    'add_users_not_supported' => 'Uppgradera till Enterprise planen för att lägga till ytterligare användaren på kontot.',
    'enterprise_plan_features' => 'Enterprise plan ger support för flera användare och bifogade filer, :link för att se lista av funktioner.',
    'return_to_app' => 'Återgå till Appen',


    // Payment updates
    'refund_payment' => 'Återbetala betalning',
    'refund_max' => 'Max:',
    'refund' => 'Återbetalning',
    'are_you_sure_refund' => 'Återbetala valda betalningar?',
    'status_pending' => 'Avvaktande',
    'status_completed' => 'Slutförd',
    'status_failed' => 'Misslyckad',
    'status_partially_refunded' => 'Delvis återbetalad',
    'status_partially_refunded_amount' => ':amount återbetalat',
    'status_refunded' => 'Återbetalad',
    'status_voided' => 'Avbruten',
    'refunded_payment' => 'Återbetalat betalning',
    'activity_39' => ':user avbröt en :payment_amount betalning :payment',
    'activity_40' => ':user återbetalade :adjustment av en :payment_amount betalning :payment',
    'card_expiration' => 'Utgår:&nbsp:expires',

    'card_creditcardother' => 'Okänd',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Blankofullmakt',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Acceptera US Bank överföringar ',
    'stripe_ach_help' => 'ACH support måste och vara aktiverat i :link',
    'ach_disabled' => 'En annan gateway är redan konfigurerad för direkt debitering.',

    'plaid' => 'Plaid',
    'client_id' => 'Klient Id',
    'secret' => 'Hemlig',
    'public_key' => 'Publik nyckel',
    'plaid_optional' => '(frivillig)',
    'plaid_environment_help' => 'När en Stripe test nyckel är inlagd kommer Plaid´s utvecklings miljö (tartan) användas.',
    'other_providers' => 'Andra leverantörer',
    'country_not_supported' => 'Landet stöds inte.',
    'invalid_routing_number' => 'Clearingnummer är inte giltigt.',
    'invalid_account_number' => 'Kontonummer inte giltigt.',
    'account_number_mismatch' => 'Kontonummer matchar inte.',
    'missing_account_holder_type' => 'Vänligen välj ett individ- eller företagskonto',
    'missing_account_holder_name' => 'Vänligen skriv kontoinnehavarens namn.',
    'routing_number' => 'Clearingnummer',
    'confirm_account_number' => 'Bekräfta kontonummer',
    'individual_account' => 'Inviduellt konto',
    'company_account' => 'Företagskonto',
    'account_holder_name' => 'Kontoinnehavarens namn',
    'add_account' => 'Lägg till konto',
    'payment_methods' => 'Betalningsmetoder',
    'complete_verification' => 'Slutför verifikation',
    'verification_amount1' => 'Belopp 1',
    'verification_amount2' => 'Belopp 2',
    'payment_method_verified' => 'Verifiering slutförd',
    'verification_failed' => 'Verifiering misslyckad',
    'remove_payment_method' => 'Ta bort betalningsmetod',
    'confirm_remove_payment_method' => 'är du säker på att du vill ta bort denna betalningsmetod?',
    'remove' => 'Ta bort',
    'payment_method_removed' => 'Betalningsmetod borttagen.',
    'bank_account_verification_help' => 'Vi har gjort två insättningar till ditt konto med beteckningen "KONTROLL". Dessa insättningar kommer att ta 1-2 arbetsdagar innan de visas på ditt kontoutdrag. Ange beloppen nedan.',
    'bank_account_verification_next_steps' => 'Vi har gjort två insättningar till ditt konto med beskrivningen "VERIFIKATION". Dessa insättningarna kommer att ta 1-2 arbetsdagar innan dom syns på ditt kontoutdrag.
När ni har pengarna, kom tillbaka till denna betalningsmetods sida och klicka på "Slutför verifikation" vid sidan om konto.',
    'unknown_bank' => 'Okänd bank',
    'ach_verification_delay_help' => 'Du kommer att kunna använd konto efter slutförd verifikation. Verifikation tar normalt 1-2 arbetsdagar.',
    'add_credit_card' => 'Lägg till kreditkort',
    'payment_method_added' => 'Lagt till betalningsmetod.',
    'use_for_auto_bill' => 'Använd för Autobill',
    'used_for_auto_bill' => 'Autobill betalningsmetod',
    'payment_method_set_as_default' => 'Sätt Autobill betalningsmetod',
    'activity_41' => ':payment_amount betalning (:payment) misslyckad',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Du måste :link.',
    'stripe_webhook_help_link_text' => 'lägg till denna URL som en slutpunkt på Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'Det gick inte att lägga till din betalningsmetod. Vänligen försök igen senare.',
    'notification_invoice_payment_failed_subject' => 'Betalning misslyckad för faktura :invoice',
    'notification_invoice_payment_failed' => 'En betalninggjord av klient :client motFaktura :invoice misslyckades. Betalningen har markerats som misslyckad och :amount harlagt tills till klientens balans.',
    'link_with_plaid' => 'Länka konto direkt med Plaid',
    'link_manually' => 'Länka manuellt',
    'secured_by_plaid' => 'Säkrad via Plaid',
    'plaid_linked_status' => 'Ditt bankkonto på :bank',
    'add_payment_method' => 'Lägg till betalningsmetod',
    'account_holder_type' => 'Kontoinnehavarens typ',
    'ach_authorization' => 'Jag godkänner :company att använda mitt bankkonto för framtida betalningar och vid behov, elektroniskt kreditera mitt konto för att korrigera felaktiga debiteringar. Jag förstår att jag kan avbryta tillståndet när som helst genom att ta bort betalningsmetod eller genom att kontakta :email.',
    'ach_authorization_required' => 'Du måste samtycka till ACH transaktioner.',
    'off' => 'Av',
    'opt_in' => 'Valt',
    'opt_out' => 'Valt bort',
    'always' => 'Alltid',
    'opted_out' => 'Valt bort',
    'opted_in' => 'Valt',
    'manage_auto_bill' => 'Editera auto-bill',
    'enabled' => 'Aktiverad',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Möjliggör PayPal-betalningar genom BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal gateway bearbetar PayPal betalningar',
    'braintree_paypal_help' => 'Du måste också :link.',
    'braintree_paypal_help_link_text' => 'Koppla PayPal till ditt BrainTree-konto',
    'token_billing_braintree_paypal' => 'Spara betalnings detaljer',
    'add_paypal_account' => 'Lägg till PayPal konto',


    'no_payment_method_specified' => 'Ingen betalningsmetod angiven',
    'chart_type' => 'Diagramtyp',
    'format' => 'Format',
    'import_ofx' => 'Importera OFX',
    'ofx_file' => 'OFX Fil',
    'ofx_parse_failed' => 'Misslyckade parse OFX fil',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Registera med WePay',
    'use_another_provider' => 'Använd en annnan leverantör',
    'company_name' => 'Företagsnamn',
    'wepay_company_name_help' => 'Detta uppges på klient kreditkortsutdrag.',
    'wepay_description_help' => 'Syftet med detta konto.',
    'wepay_tos_agree' => 'Jag godkänner :link',
    'wepay_tos_link_text' => 'WePay användarevillkor',
    'resend_confirmation_email' => 'Skicka om e-post bekräftelse',
    'manage_account' => 'Hantera konto',
    'action_required' => 'Åtgärd krävs',
    'finish_setup' => 'Slutför installationen',
    'created_wepay_confirmation_required' => 'Vänligen kolla din mejl och bekräfta epost adressen med WePay.',
    'switch_to_wepay' => 'Byt till WePay',
    'switch' => 'Växla',
    'restore_account_gateway' => 'Återställning Gateway',
    'restored_account_gateway' => 'Framgångsrikt återställt gateway',
    'united_states' => 'Förenta Staterna',
    'canada' => 'Kanada',
    'accept_debit_cards' => 'Acceptera Bankkort',
    'debit_cards' => 'Kontokort',

    'warn_start_date_changed' => 'Nästa faktura kommer att skickas på nytt startdatum.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Ursprungligt startdatum',
    'new_start_date' => 'Nytt startdatum',
    'security' => 'Säkerhet',
    'see_whats_new' => 'Se vad som är nytt i v:version',
    'wait_for_upload' => 'Snälla vänta på uppladdning av dokument slutförs.',
    'upgrade_for_permissions' => 'Uppgradera till vår Enterprise plan för att aktivera behörigheter.',
    'enable_second_tax_rate' => 'Aktivera en <b>andra momsnivå</b>',
    'payment_file' => 'Betalningsfil',
    'expense_file' => 'Kostnadsfil',
    'product_file' => 'Produktfil',
    'import_products' => 'Importera produkter',
    'products_will_create' => 'produkter kommer skapas',
    'product_key' => 'Produkt',
    'created_products' => 'Skapade/Uppdaterade :count produkt(er) utan problem',
    'export_help' => 'Använda JSON om du planerar att importera datan till Invoice Ninja.<br/>Filen innehåller kunder, produkter, fakturor, offerter och betalningar.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'JSON Fil',

    'view_dashboard' => 'Se översikt',
    'client_session_expired' => 'Din session har avslutats.',
    'client_session_expired_message' => 'Din session har gått ut. Vänligen klicka på länken i e-posten igen.',

    'auto_bill_notification' => 'Denna faktura kommer automatiskt faktureras på din :payment_method på fil den :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bankkonto',
    'auto_bill_payment_method_credit_card' => 'kredit kort',
    'auto_bill_payment_method_paypal' => 'PayPal konto',
    'auto_bill_notification_placeholder' => 'Denna faktura kommer automatiskt faktureras till ditt kreditkort på fil på förfallodag.',
    'payment_settings' => 'Betalnings inställningar',

    'on_send_date' => 'På sändningsdatum',
    'on_due_date' => 'På förfallodag',
    'auto_bill_ach_date_help' => 'ACH kommer alltid skicka räkningen automatiskt på förfallodagen.',
    'warn_change_auto_bill' => 'På grund av NACHA regler, kan förändringar i denna faktura förhindra ACH auto bill.',

    'bank_account' => 'Bankkonto',
    'payment_processed_through_wepay' => 'ACH betalningar kommer att bearbetas genom WePay.',
    'wepay_payment_tos_agree' => 'Jag acceptera WePay :terms och :privacy_policy.',
    'privacy_policy' => 'Integritetspolicy',
    'wepay_payment_tos_agree_required' => 'Du måste godkänna WePay villkor och sekretesspolicy.',
    'ach_email_prompt' => 'Vänligen skriv in din e-post adress:',
    'verification_pending' => 'Verifiering väntar',

    'update_font_cache' => 'Tvinga uppdatera sidan för att uppdatera fontcachen.',
    'more_options' => 'Fler val',
    'credit_card' => 'Betalkort',
    'bank_transfer' => 'Banköverföring',
    'no_transaction_reference' => 'Vi mottog inte en betalningstransaktions referens från gateway.',
    'use_bank_on_file' => 'Använd bank på fil',
    'auto_bill_email_message' => 'Denna faktura kommer automatiskt faktureras till betalningsmetod på fil vid förfallodatum.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Tillagd :date',
    'failed_remove_payment_method' => 'Misslyckades att ta bort betalningsmetod',
    'gateway_exists' => 'Denna gateway finns redan.',
    'manual_entry' => 'Manuell',
    'start_of_week' => 'Första veckodagen',

    // Frequencies
    'freq_inactive' => 'Inaktiv',
    'freq_daily' => 'Dagligen',
    'freq_weekly' => 'Veckovis',
    'freq_biweekly' => 'Varannan vecka',
    'freq_two_weeks' => 'Två veckor',
    'freq_four_weeks' => 'Fyra veckor',
    'freq_monthly' => 'Månadsvis',
    'freq_three_months' => 'Tre månader',
    'freq_four_months' => 'Fyra månader',
    'freq_six_months' => 'Sex månader',
    'freq_annually' => 'Årsvis',
    'freq_two_years' => 'Två år',

    // Payment types
    'payment_type_Apply Credit' => 'Tillämpa kredit',
    'payment_type_Bank Transfer' => 'Banköverföring',
    'payment_type_Cash' => 'Kontant',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa kort',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners kort',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Annat kreditkort',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Blankofullmakt',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Växla',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direkt betalning',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Redovisning & Legala',
    'industry_Advertising' => 'Annonsering',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Lantbruk',
    'industry_Automotive' => 'Bil',
    'industry_Banking & Finance' => 'Bank & Finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Broadcastning',
    'industry_Business Services' => 'Affärstjänster',
    'industry_Commodities & Chemicals' => 'Råvaror och kemikalier',
    'industry_Communications' => 'Kommunikationer',
    'industry_Computers & Hightech' => 'Datorer och avancerat',
    'industry_Defense' => 'Försvar',
    'industry_Energy' => 'Energi',
    'industry_Entertainment' => 'Underhållning',
    'industry_Government' => 'Regering',
    'industry_Healthcare & Life Sciences' => 'Hälsa och livforskning',
    'industry_Insurance' => 'Försäkring',
    'industry_Manufacturing' => 'Tillverkning',
    'industry_Marketing' => 'Marknadsföring',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Ideellt och högre forskning',
    'industry_Pharmaceuticals' => 'Läkemedel',
    'industry_Professional Services & Consulting' => 'Professionella tjänster & rådgivning',
    'industry_Real Estate' => 'Fastighet',
    'industry_Restaurant & Catering' => 'Restaurang & Catering',
    'industry_Retail & Wholesale' => 'Detaljhandel & Partihandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Resor & Lyx',
    'industry_Other' => 'Övrigt',
    'industry_Photography' => 'Fotografering',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanien',
    'country_Antarctica' => 'Antarktis',
    'country_Algeria' => 'Algeriet',
    'country_American Samoa' => '
Amerikanska Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua och Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australien',
    'country_Austria' => 'Österrike',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenien',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgien',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia',
    'country_Bosnia and Herzegovina' => 'Bosnien och Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brasilien',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'Indiska oceanen',
    'country_Solomon Islands' => 'Salomonöarna',
    'country_Virgin Islands, British' => 'Brittiska jungfruöarna',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bulgarien',
    'country_Myanmar' => 'Burma',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Vitryssland',
    'country_Cambodia' => 'Kambodja',
    'country_Cameroon' => 'Kamerun',
    'country_Canada' => 'Kanada',
    'country_Cape Verde' => 'Kap Verde',
    'country_Cayman Islands' => 'Caymanöarna',
    'country_Central African Republic' => 'Centralafrikanska republiken',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Tchad',
    'country_Chile' => 'Chile',
    'country_China' => 'Kina',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Julön',
    'country_Cocos (Keeling) Islands' => '
Cocos (Keeling) Öarna',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Kongo',
    'country_Congo, the Democratic Republic of the' => 'Kongo',
    'country_Cook Islands' => 'Cooköarna',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Kroatien',
    'country_Cuba' => 'Kuba',
    'country_Cyprus' => 'Cypern',
    'country_Czech Republic' => 'Tjeckien',
    'country_Benin' => 'Beniin',
    'country_Denmark' => 'Danmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominikanska Republiken',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Ekvatorialguinea',
    'country_Ethiopia' => 'Etiopien',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estland',
    'country_Faroe Islands' => 'Färöarna',
    'country_Falkland Islands (Malvinas)' => 'Falklandsöarna (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => '
Sydgeorgien och Sydsandwichöarna',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'Frankrike',
    'country_French Guiana' => 'Franska Guyana',
    'country_French Polynesia' => 'Franska Polynesien',
    'country_French Southern Territories' => 'Franska Sydterritorierna',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgien',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => '
Det ockuperade palestinska territoriet',
    'country_Germany' => 'Tyskland',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grekland',
    'country_Greenland' => 'Grönland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadelope',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => '
Heard- och Mcdonaldöarna',
    'country_Holy See (Vatican City State)' => 'Heliga stolen (Vatikanstaten)',
    'country_Honduras' => 'Hondura',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Ungern',
    'country_Iceland' => 'Island',
    'country_India' => 'Indien',
    'country_Indonesia' => 'Indonesien',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italien',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordanien',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea',
    'country_Korea, Republic of' => 'Korea',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Laos Demokratiska folkrepubliken',
    'country_Lebanon' => 'Libanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Lettland',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libyen',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuaien',
    'country_Luxembourg' => 'Luxemburg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldiverna',
    'country_Mali' => 'Mal',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauretanien',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexik',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongoliet',
    'country_Moldova, Republic of' => 'Moldavien',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Marocko',
    'country_Mozambique' => 'Moçambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Nederländerna',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (nederländska delen)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius och Saba',
    'country_New Caledonia' => '
Nya Kaledonien',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nya Zeeland',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Ön',
    'country_Norway' => 'Norge',
    'country_Northern Mariana Islands' => 'Nordmarianerna',
    'country_United States Minor Outlying Islands' => 'Förenta staternas avlägset belägna öar',
    'country_Micronesia, Federated States of' => 'Mikronesien av',
    'country_Marshall Islands' => 'Marshallöarna',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua Nya Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filippinerna',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polen',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumänien',
    'country_Russian Federation' => 'Ryska Federationen',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension och Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts och Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (franska delen)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre och Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent och Grenadinerna',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tomé och Principe',
    'country_Saudi Arabia' => 'Saudi Arabien',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbien',
    'country_Seychelles' => 'Seychellerna',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakien',
    'country_Viet Nam' => 'Vietnam',
    'country_Slovenia' => 'Slovenien',
    'country_Somalia' => 'Somalien',
    'country_South Africa' => 'Syd Afrika',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spanien',
    'country_South Sudan' => 'Syd Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Väst Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard och Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sverige',
    'country_Switzerland' => 'Schweiz',
    'country_Syrian Arab Republic' => 'Syrien',
    'country_Tajikistan' => 'Tadzjikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokela',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad och Tobago',
    'country_United Arab Emirates' => 'Förenade arabemiraten',
    'country_Tunisia' => 'Tunisien',
    'country_Turkey' => 'Turkiet',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks- och Caicosöarna',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraina',
    'country_Macedonia, the former Yugoslav Republic of' => 'Makedonien, fd jugoslaviska republiken',
    'country_Egypt' => 'Egypten',
    'country_United Kingdom' => 'Storbritannien',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania',
    'country_United States' => 'Förenta Staterna',
    'country_Virgin Islands, U.S.' => 'Jungfruöarna, US.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarianska republiken',
    'country_Wallis and Futuna' => 'Wallis och Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yeme',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brasiliansk Portugisiska',
    'lang_Croatian' => 'Kroatiska',
    'lang_Czech' => 'Tjeck',
    'lang_Danish' => 'Danska',
    'lang_Dutch' => 'Tyska',
    'lang_English' => 'Engelska',
    'lang_French' => 'Franska',
    'lang_French - Canada' => 'Franska - Kanadensiska',
    'lang_German' => 'Tyska',
    'lang_Italian' => 'Italenska',
    'lang_Japanese' => 'Japanska',
    'lang_Lithuanian' => 'Litauiska',
    'lang_Norwegian' => 'Norska',
    'lang_Polish' => 'Polska',
    'lang_Spanish' => 'Spanska',
    'lang_Spanish - Spain' => 'Spanska',
    'lang_Swedish' => 'Svenska',
    'lang_Albanian' => 'Albanska',
    'lang_Greek' => 'Grekiska',
    'lang_English - United Kingdom' => 'Engelska - Storbritannien',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenien',
    'lang_Finnish' => 'Finska',
    'lang_Romanian' => 'Rumänska',
    'lang_Turkish - Turkey' => 'Turkiska - Turkiet',
    'lang_Portuguese - Brazilian' => 'Portugisiska - Brasilianska',
    'lang_Portuguese - Portugal' => 'Portugisiska  - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Redovisning & Legala',
    'industry_Advertising' => 'Annonsering',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Lantbruk',
    'industry_Automotive' => 'Bil',
    'industry_Banking & Finance' => 'Bank & Finans',
    'industry_Biotechnology' => 'Bioteknologi',
    'industry_Broadcasting' => 'Broadcastning',
    'industry_Business Services' => 'Affärstjänster',
    'industry_Commodities & Chemicals' => 'Råvaror och kemikalier',
    'industry_Communications' => 'Kommunikationer',
    'industry_Computers & Hightech' => 'Datorer och avancerat',
    'industry_Defense' => 'Försvar',
    'industry_Energy' => 'Energi',
    'industry_Entertainment' => 'Underhållning',
    'industry_Government' => 'Regering',
    'industry_Healthcare & Life Sciences' => 'Hälsa och livforskning',
    'industry_Insurance' => 'Försäkring',
    'industry_Manufacturing' => 'Tillverkning',
    'industry_Marketing' => 'Marknadsföring',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Ideellt och högre forskning',
    'industry_Pharmaceuticals' => 'Läkemedel',
    'industry_Professional Services & Consulting' => 'Professionella tjänster & rådgivning',
    'industry_Real Estate' => 'Fastighet',
    'industry_Retail & Wholesale' => 'Detaljhandel & Partihandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Resor & Lyx',
    'industry_Other' => 'Övrigt',
    'industry_Photography' => 'Fotografering',

    'view_client_portal' => 'Se klient portal',
    'view_portal' => 'Se portal',
    'vendor_contacts' => 'Leverantörs kontakter',
    'all' => 'Alla',
    'selected' => 'Vald',
    'category' => 'Kategori',
    'categories' => 'Kategorier',
    'new_expense_category' => 'Ny utgifts kategori',
    'edit_category' => 'Ändra kategori',
    'archive_expense_category' => 'Arkiv kategori',
    'expense_categories' => 'Utgifts kategorier',
    'list_expense_categories' => 'Lista utgifts kategorier',
    'updated_expense_category' => 'Framgångsrikt uppdaterat kostnadskategori',
    'created_expense_category' => 'Framgångsrikt skapat kostnadskategori',
    'archived_expense_category' => 'Framgångsrikt arkiverat kostnadskategori',
    'archived_expense_categories' => 'Framgångsrikt arkiverat :count kostnadskategori',
    'restore_expense_category' => 'Återställd kostnadskategori',
    'restored_expense_category' => 'Framgångsrikt återställt kostnadskategori',
    'apply_taxes' => 'Lägg på skatt',
    'min_to_max_users' => ':min till :max användare',
    'max_users_reached' => 'Maximalt antal användare har uppnåtts.',
    'buy_now_buttons' => 'Köp Nu knappar',
    'landing_page' => 'Landningssida',
    'payment_type' => 'Betalningstyp',
    'form' => 'Form',
    'link' => 'Länk',
    'fields' => 'Fält',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Notis: kunden och fakturan skapades även om transaktionen inte är komplett',
    'buy_now_buttons_disabled' => '
Den här funktionen kräver att en produkt skapas och en betalningsgateway är konfigurerad.',
    'enable_buy_now_buttons_help' => 'Aktivera stöd för Köp Nu knappar',
    'changes_take_effect_immediately' => 'Notera: ändringar tar effekt direkt.',
    'wepay_account_description' => 'Betalningsgateway för Invoice Ninja',
    'payment_error_code' => 'Det blev fel när ni behandlade din betalning [:code]. Försök igen senare.',
    'standard_fees_apply' => 'Avgift: 2.9%/1.2% [Bankkort/Bankbetalning] + $0.30 för varje dragning.',
    'limit_import_rows' => 'Data måste importeras i batcher av :count rader eller mindre',
    'error_title' => 'Något gick fel',
    'error_contact_text' => 'Om du vill hjälpa till, vänligen e-posta oss på :mailaddress',
    'no_undo' => 'Varning: Detta kan inte ångras.',
    'no_contact_selected' => 'Välj en kontakt',
    'no_client_selected' => 'Välj en klient',

    'gateway_config_error' => 'Det kan hjälpa till att sätta nya lösenord eller generera nya API-nycklar.',
    'payment_type_on_file' => ':type på fil',
    'invoice_for_client' => 'Faktura :Invoice för :client',
    'intent_not_found' => 'Förlåt, jag är inte säker på vad du frågar.',
    'intent_not_supported' => 'Förlåt, jag kan inte göra det.',
    'client_not_found' => 'Jag kunde inte hitta klienten.',
    'not_allowed' => 'Ledsen, du har inte de nödvändiga rättigheterna',
    'bot_emailed_invoice' => 'Din faktura har skickats.',
    'bot_emailed_notify_viewed' => 'Jag e-postar dig när den är visad.',
    'bot_emailed_notify_paid' => 'Jag e-postar dig när den är betald.',
    'add_product_to_invoice' => 'Lägg till 1 :produkt',
    'not_authorized' => 'Du är inte behörig.',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Tack! Jag har skickat ett mejl till dig med din säkerhetskod.',
    'bot_welcome' => 'Ditt konto är verifierat.',
    'email_not_found' => 'Jag kunde inte hitta ett tillgängligt konto för :email',
    'invalid_code' => 'Koden var inte korrekt',
    'security_code_email_subject' => 'Säkerhetskod för Invoice Ninja Bot.',
    'security_code_email_line1' => 'Detta är din Invoice Ninja Bot säkerhetskod.',
    'security_code_email_line2' => 'Notering: Upphör om 10 minuter.',
    'bot_help_message' => 'Jag stöder för närvarande: <br/> • Skapa \ Uppdatera \ Mejla en faktura <br/> • Produktlista <br/> Till exempel: <br/> <i> Fakturera bob för 2 biljetter, ange ett slutdatum på nästa torsdag och rabatten till 10 procent </ i>',
    'list_products' => 'Lista produkter',

    'include_item_taxes_inline' => 'Inkludera <b>rad moms i totalmoms</b>',
    'created_quotes' => 'Framgångsrikt skapat :count offert(er)',
    'limited_gateways' => 'Notering: We stödjer ett kreditkorts gateway per företag.',

    'warning' => 'Varning',
    'self-update' => 'Uppdatera',
    'update_invoiceninja_title' => 'Uppdatera Invoice Ninja',
    'update_invoiceninja_warning' => 'Innan ni uppgraderar Invoice Ninja, skapa en backup av er databaser och filer!',
    'update_invoiceninja_available' => 'En ny version av Invoice Ninja finns tillgänglig.',
    'update_invoiceninja_unavailable' => 'Ingen ny version av Invoice Ninja finns tillgänglig.',
    'update_invoiceninja_instructions' => 'Vänligen installera <strong>:version</strong> genom att klicka på <em>Uppdatera nu</em> knappen nedan. Ni blir sedan omdirigerad till instrumentpanelen.',
    'update_invoiceninja_update_start' => 'Uppdatera nu',
    'update_invoiceninja_download_start' => 'Ladda ner :version',
    'create_new' => 'Skapa Ny',

    'toggle_navigation' => 'Aktivera Navigering',
    'toggle_history' => 'Aktivera Historik',
    'unassigned' => 'Otilldelad',
    'task' => 'Uppgift',
    'contact_name' => 'Kontakt namn',
    'city_state_postal' => 'Stad/Län/Postnummer',
    'custom_field' => 'Anpassat Fält',
    'account_fields' => 'Företags fält',
    'facebook_and_twitter' => 'Facebook och Twitter',
    'facebook_and_twitter_help' => 'Följ våra feeds för att stödja vårt projekt',
    'reseller_text' => 'Notis: white-label licensen är tänkt för privat bruk, vänligen eposta oss på :email om du vill vara återförsäljare till appen.',
    'unnamed_client' => 'Namnlös Klient',

    'day' => 'Dag',
    'week' => 'Vecka',
    'month' => 'Månad',
    'inactive_logout' => 'Du har blivit utloggad p.g.a. inaktivitet',
    'reports' => 'Rapporter',
    'total_profit' => 'Summa vinst',
    'total_expenses' => 'Summa utgifter',
    'quote_to' => 'Offert till',

    // Limits
    'limit' => 'Gräns',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Inga gränser',
    'set_limits' => 'Sätt :gateway_type gränser',
    'enable_min' => 'Aktivera min',
    'enable_max' => 'Aktivera max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Den faktura uppfyller inte gränserna för denna betalningstyp.',

    'date_range' => 'Datumintervall',
    'raw' => 'Rå',
    'raw_html' => 'Rå HTML',
    'update' => 'Uppdatera',
    'invoice_fields_help' => 'Dra och släpp fält för att ändra deras ordning och plats',
    'new_category' => 'Ny Kategori',
    'restore_product' => 'Återställ Produkt',
    'blank' => 'Blank',
    'invoice_save_error' => 'Det uppstod ett problem vid sparande av din faktura',
    'enable_recurring' => 'Aktivera återkommande',
    'disable_recurring' => 'Inaktivera återkommande',
    'text' => 'Text',
    'expense_will_create' => 'kostnad kommer att skapas',
    'expenses_will_create' => 'kostnad kommer att skapas',
    'created_expenses' => 'Framgångsrikt skapat :count kostnad(er)',

    'translate_app' => 'Hjälp oss förbättra vår översättning via :link',
    'expense_category' => 'Kostnads kategori',

    'go_ninja_pro' => 'Gå Ninja Pro!',
    'go_enterprise' => 'Gå Enterprise!',
    'upgrade_for_features' => 'Uppgradera för mer funktioner',
    'pay_annually_discount' => 'Betala årligen för 10 månader + 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'dindoman.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Anpassa varje aspekt av din faktura!',
    'enterprise_upgrade_feature1' => 'Sätt rättigheter för flera användare.',
    'enterprise_upgrade_feature2' => 'Bifoga 3:e filer för fakturor & kostnader',
    'much_more' => 'Mycket mer!',
    'all_pro_fetaures' => 'Plus alla pro funktioner!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Kod',

    'buy_license' => 'Köp Licens',
    'apply_license' => 'Uppge Licens',
    'submit' => 'Skicka',
    'white_label_license_key' => 'Licensnyckel',
    'invalid_white_label_license' => 'Den vita etikettlicensen är inte giltig',
    'created_by' => 'Skapad av :name',
    'modules' => 'Moduler',
    'financial_year_start' => 'Första månaden på året',
    'authentication' => 'Autentisering',
    'checkbox' => 'Kryssruta',
    'invoice_signature' => 'Signatur',
    'show_accept_invoice_terms' => 'Faktura villkor kryssruta',
    'show_accept_invoice_terms_help' => 'Kräv att klienten accepterar faktura villkoren.',
    'show_accept_quote_terms' => 'Offert villkors kryssruta',
    'show_accept_quote_terms_help' => 'Kräv att klienten accepterar offert villkoren.',
    'require_invoice_signature' => 'Faktura signatur',
    'require_invoice_signature_help' => 'Kräv signatur av klient.',
    'require_quote_signature' => 'Offert signatur',
    'require_quote_signature_help' => 'Kräv signatur av klient.',
    'i_agree' => 'Jag accepterar villkoren',
    'sign_here' => 'Vänligen signera här:',
    'authorization' => 'Tillstånd',
    'signed' => 'Signerad',

    // BlueVine
    'bluevine_promo' => 'Få flexibla affärssystem krediter och fakturabelåning hjälp BlueVine.',
    'bluevine_modal_label' => 'Registrera med BlueVine',
    'bluevine_modal_text' => '<h3>Snabb finansiering av ditt företag. Inget pappersarbete.</h3>
<ul><li>Flexibel kredit och fakturaköp.</li></ul>',
    'bluevine_create_account' => 'Skapa konto',
    'quote_types' => 'Få offertför',
    'invoice_factoring' => 'Faktura facto',
    'line_of_credit' => 'Kredit',
    'fico_score' => 'Din FICO poäng',
    'business_inception' => 'Affärs startkod',
    'average_bank_balance' => 'Genomsnitt bankkonto balans.',
    'annual_revenue' => 'Årsomsättning',
    'desired_credit_limit_factoring' => 'Önskad faktura factogräns',
    'desired_credit_limit_loc' => 'Önskad kreditgräns',
    'desired_credit_limit' => 'Önskad kreditgräns',
    'bluevine_credit_line_type_required' => 'Du måste välja minst en',
    'bluevine_field_required' => 'Detta fält krävs',
    'bluevine_unexpected_error' => 'Ett oförutsett fel uppkom.',
    'bluevine_no_conditional_offer' => 'Mer information krävs innan ni får en offert. Vänligen klicka nedan.',
    'bluevine_invoice_factoring' => 'Faktura facto',
    'bluevine_conditional_offer' => 'Villkorligt erbjudande',
    'bluevine_credit_line_amount' => 'Kredit linje',
    'bluevine_advance_rate' => 'Matningshastighet',
    'bluevine_weekly_discount_rate' => 'Veckorabattsats',
    'bluevine_minimum_fee_rate' => 'Minimiavgift',
    'bluevine_line_of_credit' => 'Kreditlinje',
    'bluevine_interest_rate' => 'Ränta',
    'bluevine_weekly_draw_rate' => 'Vecko dratakt',
    'bluevine_continue' => 'Fortsätt till BlueVine',
    'bluevine_completed' => 'BlueVine registrering slutförd',

    'vendor_name' => 'Leverantör',
    'entity_state' => 'Tillstånd',
    'client_created_at' => 'Datum skapad',
    'postmark_error' => 'Ett problem uppstod när mail skulle skickas genom Postmark :link',
    'project' => 'Projekt',
    'projects' => 'Projekt',
    'new_project' => 'Nytt Projekt',
    'edit_project' => 'Ändra Produkt',
    'archive_project' => 'Arkivera Projekt',
    'list_projects' => 'Lista Projekt',
    'updated_project' => 'Projektet uppdaterat',
    'created_project' => 'Projekt skapat',
    'archived_project' => 'Projekt arkiverat',
    'archived_projects' => ':count projekt arkiverade',
    'restore_project' => 'Återställ projekt',
    'restored_project' => 'Projekt återställt',
    'delete_project' => 'Ta bort projekt',
    'deleted_project' => 'Projekt borttaget',
    'deleted_projects' => ':count projekt borttagna',
    'delete_expense_category' => 'Ta bort kategori',
    'deleted_expense_category' => 'Kategori borttagen',
    'delete_product' => 'Ta bort produkt',
    'deleted_product' => 'Produkt borttagen',
    'deleted_products' => ':count produkter borttagna',
    'restored_product' => 'Produkt återställd',
    'update_credit' => 'Uppdatera Kreditfaktura',
    'updated_credit' => 'Kreditfaktura uppdaterad',
    'edit_credit' => 'Redigera Kreditfaktura',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Ersätt den inbyggda PDF-visaren i :chrome_link och :firefox_link.
<br />Aktivera detta om din webbläsare automatiskt laddar hem PDF:erna.',
    'force_pdfjs' => 'Förhindra nerladdning',
    'redirect_url' => 'Omdirigeringsadress',
    'redirect_url_help' => 'Alternativt specificera en URL att gå till efter en betalning är gjord.',
    'save_draft' => 'Spara utkast',
    'refunded_credit_payment' => 'Återbetalad kredit betalning',
    'keyboard_shortcuts' => 'Tangentbords genvägar',
    'toggle_menu' => 'Växla Meny',
    'new_...' => 'Ny ...',
    'list_...' => 'Lista ...',
    'created_at' => 'Skapat datum',
    'contact_us' => 'Kontakta oss',
    'user_guide' => 'Användarhjälp',
    'promo_message' => 'Uppgradera innan :expires och få :amount rabatt på ditt första år med Pro eller Enterprise paketet.',
    'discount_message' => ':amount av utgående :expires',
    'mark_paid' => 'Markera betald',
    'marked_sent_invoice' => 'Markerade utan problem fakturan som skickad',
    'marked_sent_invoices' => 'Markerade utan problem fakturorna som skickade',
    'invoice_name' => 'Faktura',
    'product_will_create' => 'Produkt kommer skapas',
    'contact_us_response' => 'Tack för ditt meddelade! Vi försöker svara snarast möjligt.',
    'last_7_days' => 'Senaste 7 dagarna',
    'last_30_days' => 'Senaste 30 dagarna',
    'this_month' => 'Denna månaden',
    'last_month' => 'Senaste månaden',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Senaste året',
    'custom_range' => 'Anpassat intervall',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Kräv',
    'license_expiring' => 'Notera: Din licens kommer gå ut om :count dagar, :link för att förnya den.',
    'security_confirmation' => 'Din e-post har blivit bekräftad',
    'white_label_expired' => 'Din white label licens har gått ut, vänligen fundera på att förnya det för att hjälpa till att supporta vårt projekt.',
    'renew_license' => 'Förnya licens',
    'iphone_app_message' => 'Överväg nerladdning av :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Inloggad',
    'switch_to_primary' => 'Byta till ditt primära företag (:name) för att hantera din prenumeration.',
    'inclusive' => 'Inklusive',
    'exclusive' => 'Exklusive',
    'postal_city_state' => 'Postadress/Stad/Stat',
    'phantomjs_help' => 'I vissa fall använder appen :link_phantom för att skapa PDF, installera :link_docs för att skapa den lokalt.',
    'phantomjs_local' => 'Använder lokal PhantomJS',
    'client_number' => 'Kundnummer',
    'client_number_help' => 'Specificera ett prefix eller använd ett anpassat mönster för att dynamiskt sätta kundnummer.',
    'next_client_number' => 'Nästa kundnummer är :number',
    'generated_numbers' => 'Genererade nummer',
    'notes_reminder1' => 'Första påminnelsen',
    'notes_reminder2' => 'Andra påminnelsen',
    'notes_reminder3' => 'Tredje påminnelsen',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'Eposta hemlig kopia ',
    'tax_quote' => 'Momssats',
    'tax_invoice' => 'Moms faktura',
    'emailed_invoices' => 'E-postade fakturorna utan problem',
    'emailed_quotes' => 'E-postade offerterna utan problem',
    'website_url' => 'Hemsidans URL',
    'domain' => 'Domän',
    'domain_help' => 'Används i kundportalen och när e-post skickas.',
    'domain_help_website' => 'Används när e-post skickas.',
    'import_invoices' => 'Importera fakturor',
    'new_report' => 'Ny Rapport',
    'edit_report' => 'Ändra Rapport',
    'columns' => 'Kolumner',
    'filters' => 'Filter',
    'sort_by' => 'Sortera efter',
    'draft' => 'Utkast',
    'unpaid' => 'Obetald',
    'aging' => 'Börjar bli gammal',
    'age' => 'Ålder',
    'days' => 'Dagar',
    'age_group_0' => '0 - 30 Dagar',
    'age_group_30' => '30 - 60 Dagar',
    'age_group_60' => '60 - 90 Dagar',
    'age_group_90' => '90 - 120 Dagar',
    'age_group_120' => '120+ Dagar',
    'invoice_details' => 'Faktura detaljer',
    'qty' => 'Mängd',
    'profit_and_loss' => 'Förtjänst och Förlust',
    'revenue' => 'Omsättning',
    'profit' => 'Förtjänst',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Gruppera datum på',
    'year' => 'År',
    'view_statement' => 'Se transaktion',
    'statement' => 'Transaktionsdatum',
    'statement_date' => 'Sista transaktionsdatum',
    'mark_active' => 'Markera aktiv',
    'send_automatically' => 'Skicka automatiskt',
    'initial_email' => 'Påbörja epost',
    'invoice_not_emailed' => 'Denna fakturan har inte epostats.',
    'quote_not_emailed' => 'Denna offerten har inte epostats.',
    'sent_by' => 'Skickad av :user',
    'recipients' => 'Mottagare',
    'save_as_default' => 'Spara som standard',
    'start_of_week_help' => 'Använd av <b>datum</b> väljare',
    'financial_year_start_help' => 'Används av <b>datum</b> väljare.',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Detta året',

    // Updated login screen
    'ninja_tagline' => 'Skapa. Skicka. Få betalt.',
    'login_or_existing' => 'Eller logga in med ett kopplat konto.',
    'sign_up_now' => 'Ansök nu',
    'not_a_member_yet' => 'Inte medlem ännu?',
    'login_create_an_account' => 'Skapa ett konto!',

    // New Client Portal styling
    'invoice_from' => 'Fakturor från:',
    'email_alias_message' => 'Vi kräver att varje företag har en unik epost.<br/>Överväg att använda ett alias. T.ex. email+label@example.com',
    'full_name' => 'Hela namnet',
    'month_year' => 'MÅNAD/ÅR',
    'valid_thru' => 'Giltigt\ntill',

    'product_fields' => 'Produkt fält',
    'custom_product_fields_help' => 'Lägg till ett fält när en produkt eller faktura skapas och visa rubriken samt värdet på PDFen.',
    'freq_two_months' => 'Två månader',
    'freq_yearly' => 'Årligen',
    'profile' => 'Profil',
    'payment_type_help' => 'Sätt standard <b>betalsätt</b>.',
    'industry_Construction' => 'Uppbyggnad',
    'your_statement' => 'Dina transaktioner',
    'statement_issued_to' => 'Transaktioner utförda till',
    'statement_to' => 'Transaktioner till',
    'customize_options' => 'Anpassade alternativ',
    'created_payment_term' => 'Skapade betalningsvillkor utan problem',
    'updated_payment_term' => 'Uppdaterade betalningsvillkor utan problem',
    'archived_payment_term' => 'Arkiverat betalningsvillkor utan problem',
    'resend_invite' => 'Skicka inbjudan igen',
    'credit_created_by' => 'Kredit skapad från betalning :transaction_reference',
    'created_payment_and_credit' => 'Skapade betalning och kredit utan problem',
    'created_payment_and_credit_emailed_client' => 'Skapade betalning och kredit, och epostade kunden',
    'create_project' => 'Skapa projekt',
    'create_vendor' => 'Skapa tillverkare',
    'create_expense_category' => 'Skapa kategori',
    'pro_plan_reports' => ':link för att aktivera rapporter genom att aktivera Pro Planen',
    'mark_ready' => 'Markera klar',

    'limits' => 'Gränser',
    'fees' => 'Avgifter',
    'fee' => 'Avgift',
    'set_limits_fees' => 'Sätt :gateway_type Gränser/Avgifter',
    'fees_tax_help' => 'Tillåt rad skatter att säga avgift skattesatser.',
    'fees_sample' => 'Avgift för en :amount Faktura hade blivit :total.',
    'discount_sample' => 'Rabatten för en :amount faktura skulle bli :total.',
    'no_fees' => 'Inga avgifter',
    'gateway_fees_disclaimer' => 'Varning: Inte alla stater/betalning gateways tillåter tilläggsavgifter, vänligen referera till lokala lagar/villkor.',
    'percent' => 'Procent',
    'location' => 'Position',
    'line_item' => 'Rad',
    'surcharge' => 'Tilläggsavgift',
    'location_first_surcharge' => 'Aktiverad - Första tilläggsavgiften',
    'location_second_surcharge' => 'Aktiverad - Andra tilläggsavgiften',
    'location_line_item' => 'Aktiverad - Rad',
    'online_payment_surcharge' => 'Online betalningstillägg',
    'gateway_fees' => 'Gateway avgifter',
    'fees_disabled' => 'Avgifter är inaktiverade',
    'gateway_fees_help' => 'Lägger automatiskt en online-betalningsavgift/rabatt.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'Om det finns obetalda fakturor med avgifter måste dom uppdateras manuellt.',
    'fees_surcharge_help' => 'Anpassa tilläggsavgift :link.',
    'label_and_taxes' => 'stämpel och skatter',
    'billable' => 'Fakturerbar',
    'logo_warning_too_large' => 'Bilden är för stor.',
    'logo_warning_fileinfo' => 'Varning: För att stödja gifs måste fileInfo PHP extensions vara aktiverat.',
    'logo_warning_invalid' => 'Det var ett problem med att läsa bilden, vänligen testa ett annat format.',

    'error_refresh_page' => 'Ett fel uppstod, vänligen uppdatera sidan och försök igen.',
    'data' => 'Information',
    'imported_settings' => 'Framgångsrikt importerat inställningar',
    'reset_counter' => 'Återställ räknare',
    'next_reset' => 'Nästa återställning',
    'reset_counter_help' => 'Återställ automatiskt faktura och offert räknare.',
    'auto_bill_failed' => 'Auto-betalning för Faktura :Invoice_number misslyckades',
    'online_payment_discount' => 'Kortbetalnings rabatt',
    'created_new_company' => 'Framgångsrikt skapat nytt företag',
    'fees_disabled_for_gateway' => 'Avgifter är inaktiverade för denna gateway.',
    'logout_and_delete' => 'Logga ut/Ta bort konto',
    'tax_rate_type_help' => 'Inklusive skatt värde justeras på raden när det väljs.<br/>Endast exklusive skatt värde kan användas som standard.',
    'invoice_footer_help' => 'Använd $pageNumber och $pageCount för att visa sidinformation.',
    'credit_note' => 'Kreditnota',
    'credit_issued_to' => 'Kredit skapat för',
    'credit_to' => 'Kreditera till',
    'your_credit' => 'Din kredit',
    'credit_number' => 'Kreditnummer',
    'create_credit_note' => 'Skapa kreditnota',
    'menu' => 'Meny',
    'error_incorrect_gateway_ids' => 'Fel: En eller flera gatewaytabeller har fel ids.',
    'purge_data' => 'Rensa uppgifter.',
    'delete_data' => 'Ta bort uppgifter',
    'purge_data_help' => 'Ta bort all data permanent men behåll konto och inställningar.',
    'cancel_account_help' => 'Permanent borttagning av konto tillsammans med all information och inställningar.',
    'purge_successful' => 'Rensade utan problem företags data',
    'forbidden' => 'Förbjudet',
    'purge_data_message' => 'Varning: Detta kommer permanent ta bort din information, det finns ingen återvända.',
    'contact_phone' => 'Kontakt telefon',
    'contact_email' => 'Kontakt e-post',
    'reply_to_email' => 'Reply-To E-post',
    'reply_to_email_help' => 'Specifiera reply-to adress för klient mail.',
    'bcc_email_help' => 'Inkludera denna adress privat med kundens e-post.',
    'import_complete' => 'Din import har slutförts utan problem.',
    'confirm_account_to_import' => 'Vänligen bekräfta ditt konto för att importera data.',
    'import_started' => 'Din import har startat, vi skickar ett epost meddelande när det är klart.',
    'listening' => 'Lyssnar....',
    'microphone_help' => 'Säg "ny faktura till [kund]" eller "visa mig [kund]´s arkiverade betalningar"',
    'voice_commands' => 'Röst kommando',
    'sample_commands' => 'Test kommandon',
    'voice_commands_feedback' => 'Vi arbetat aktivt med att förbättra denna funktion, om där är ett kommando du vill vi ska stödja skicka ett mail till :email',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Fastpris i förskott - Money Order',
    'archived_products' => 'Arkiverade :count produkter utan problem',
    'recommend_on' => 'Vi rekommenderar <b>aktivering</b> av denna inställning.',
    'recommend_off' => 'Vi rekommenderar <b>inaktivering</b> av denna inställning.',
    'notes_auto_billed' => 'Automatisk fakturering',
    'surcharge_label' => 'Tilläggsetikett',
    'contact_fields' => 'Kontaktfält',
    'custom_contact_fields_help' => 'Lägg till ett fält vid skapandet av kontakt och möjliggör visandet av rubriken samt värdet på PDF´n.',
    'datatable_info' => 'Visar :start till :end av :total poster',
    'credit_total' => 'Kredit Totalt',
    'mark_billable' => 'Markera debiterbar',
    'billed' => 'Fakturerad',
    'company_variables' => 'Företagsvariabler',
    'client_variables' => 'Klientvariabler',
    'invoice_variables' => 'Fakturavariabler',
    'navigation_variables' => 'Navigationsvariabler',
    'custom_variables' => 'Anpassade variabler',
    'invalid_file' => 'Ogiltig filtyp',
    'add_documents_to_invoice' => 'Bifoga dokument till fakturan',
    'mark_expense_paid' => 'Markera som betald',
    'white_label_license_error' => 'Misslyckas att validera licensen, kolla storage/logs/laravel-error.log för mer detaljer.',
    'plan_price' => 'Pris plan',
    'wrong_confirmation' => 'Ogiltig bekräftelsekod',
    'oauth_taken' => 'Kontot är redan registerat',
    'emailed_payment' => 'Epostade betalningen utan problem',
    'email_payment' => 'Eposta betalning',
    'invoiceplane_import' => 'Använd :link för att migrera din data från InvoicePlane.',
    'duplicate_expense_warning' => 'Varning: Denna :link kan vara en dubblett',
    'expense_link' => 'utgifter',
    'resume_task' => 'fortsätt uppgift',
    'resumed_task' => 'fortsatt uppgiften utan problem',
    'quote_design' => 'Offert design',
    'default_design' => 'Standard design',
    'custom_design1' => 'Anpassad design 1',
    'custom_design2' => 'Anpassad design 2',
    'custom_design3' => 'Anpassad design 3',
    'empty' => 'Tom',
    'load_design' => 'Ladda design',
    'accepted_card_logos' => 'Accepterade kort logos',
    'phantomjs_local_and_cloud' => 'Använder lokal PhantomJS, återgår till phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics nyckel',
    'analytics_key_help' => 'Följ betalningar via :link',
    'start_date_required' => 'Start datum är nödvändig',
    'application_settings' => 'Program inställning',
    'database_connection' => 'Databas koppling',
    'driver' => 'Driver',
    'host' => 'Värd',
    'database' => 'Databas',
    'test_connection' => 'Testa koppling',
    'from_name' => 'Från namn',
    'from_address' => 'Från adress',
    'port' => 'Port',
    'encryption' => 'Kryptering',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Skicka test meddelande',
    'select_label' => 'Välj rubrik',
    'label' => 'Rubrik',
    'service' => 'Service',
    'update_payment_details' => 'Uppdatera betalnings detaljer',
    'updated_payment_details' => 'Uppdaterade betalningsdetaljer utan problem',
    'update_credit_card' => 'Uppdatera kreditkort',
    'recurring_expenses' => 'Återkommande utgifter',
    'recurring_expense' => 'Återkommande utgift',
    'new_recurring_expense' => 'Ny återkommande utgift',
    'edit_recurring_expense' => 'Ändra återkommande utgift',
    'archive_recurring_expense' => 'Arkivera återkommande utgift',
    'list_recurring_expense' => 'Lista återkommande utgifter',
    'updated_recurring_expense' => 'Uppdaterade återkommande utgift utan problem',
    'created_recurring_expense' => 'Skapade återkommande utgift utan problem',
    'archived_recurring_expense' => 'Arkiverade återkommande utgift utan problem',
    'restore_recurring_expense' => 'Återställ återkommande utgift',
    'restored_recurring_expense' => 'Återställde återkommande utgifter utan problem',
    'delete_recurring_expense' => 'Ta bort återkommande utgifter',
    'deleted_recurring_expense' => 'Tog bort projektet utan problem',
    'view_recurring_expense' => 'Se återkommande utgifter',
    'taxes_and_fees' => 'Skatter och avgifter',
    'import_failed' => 'Import misslyckades',
    'recurring_prefix' => 'Återkommande prefix',
    'options' => 'Val',
    'credit_number_help' => 'Specificera ett prefix eller använd ett egendefinierat värde för att dynamiskt sätta kredit värdet på negativa fakturor.',
    'next_credit_number' => 'Nästa kreditkortsnummer är :number.',
    'padding_help' => 'Antal nollor för att fylla ut numret',
    'import_warning_invalid_date' => 'Varning: Datumformatet verkar vara ogiltigt',
    'product_notes' => 'Produkt notiser',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link för att få dina Stripe API nycklar.',
    'error_app_key_set_to_default' => 'Fel: APP_KEY är satt till ett standard värde, för att uppdatera det backupa din databas och sen kör <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Ändra förseningsavgift',
    'late_fee_amount' => 'Förseningsavgifts summa',
    'late_fee_percent' => 'Förseningsavgifts procent',
    'late_fee_added' => 'Förseningsavgift tillagt den :date',
    'download_invoice' => 'Hämta faktura',
    'download_quote' => 'Hämta offert',
    'invoices_are_attached' => 'Din faktura PDF är bifogad.',
    'downloaded_invoice' => 'Ett e-post med faktura PDF kommer skickas',
    'downloaded_quote' => 'Ett e-post med offert PDF kommer skickas',
    'downloaded_invoices' => 'Ett e-post med faktura PDFer kommer skickas',
    'downloaded_quotes' => 'Ett e-post med offert PDFer kommer skickas',
    'clone_expense' => 'Klona utgift',
    'default_documents' => 'Standard dokument',
    'send_email_to_client' => 'Skicka e-post till kunden',
    'refund_subject' => 'Återbetalning hanterad',
    'refund_body' => 'Du har fått en återbetalning på :amount för faktura :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'Brittiska pund',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danska kronor',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Svenska kronor',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norska kronor',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Säkerställ att du använder Engelska versionen av filerna<br/>Vi använder kolumn headern för att matcha fälten.',
    'tax1' => 'Första moms',
    'tax2' => 'Andra moms',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporteringsformat',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Kontakt Förnamn',
    'contact_last_name' => 'Kontakt Efternamn',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Valuta',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'kommentarer',

    'item_product' => 'Artikel Produkt',
    'item_notes' => 'Artikel Noteringar',
    'item_cost' => 'Artikel Kostnad',
    'item_quantity' => 'Artikel Antal',
    'item_tax_rate' => 'Artikel momssats',
    'item_tax_name' => 'Artikel moms namn',
    'item_tax1' => 'Artikel moms1',
    'item_tax2' => 'Artikel moms2',

    'delete_company' => 'Ta bort företag',
    'delete_company_help' => 'Ta permanent bort bolaget tillsammans med all data och inställningar.',
    'delete_company_message' => 'Varning: Detta kommer permanent ta bort till bolag, det finns ingen återvändo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Inkludera fel',
    'include_errors_help' => 'Inkludera :link från lagring/loggar/laravel-error.log',
    'recent_errors' => 'senaste felen',
    'customer' => 'Kund',
    'customers' => 'Kunder',
    'created_customer' => 'Skapat kund utan problem',
    'created_customers' => 'Skapat :count kunder utan problem',

    'purge_details' => 'All data i ditt bolag (:account) har tagits bort utan problem.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Ditt bolag (:account) har tagits bort utan problem',
    'deleted_account_details' => 'Ditt konto (:account) har tagits bort utan problem.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Acceptera Allpay',
    'enable_sofort' => 'Acceptera EU-banköverföringar',
    'stripe_alipay_help' => 'Dessa gateways behöver också aktiveras i :link.',
    'calendar' => 'Kalender',
    'pro_plan_calendar' => ':link för att aktivera kalender genom att uppgradera till Pro Planen',

    'what_are_you_working_on' => 'Vad jobbar du med?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Uppdatera',
    'filter_sort' => 'Filtrera/Sortera',
    'no_description' => 'Ingen beskrivning',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Spara eller avbryt ändringar',
    'discard_changes' => 'Avbryt ändringar',
    'tasks_not_enabled' => 'Uppgifter är inte aktiverade',
    'started_task' => 'Startat uppgift utan problem',
    'create_client' => 'Skapa kund',

    'download_desktop_app' => 'Ladda ner skrivbords appen',
    'download_iphone_app' => 'Ladda ner iPhone appen',
    'download_android_app' => 'Ladda ner Android appen',
    'time_tracker_mobile_help' => 'Dubbelklicka för att välja den',
    'stopped' => 'Stoppad',
    'ascending' => 'Stigande',
    'descending' => 'Fallande',
    'sort_field' => 'Sortera',
    'sort_direction' => 'Riktning',
    'discard' => 'Kassera',
    'time_am' => 'FM',
    'time_pm' => 'EM',
    'time_mins' => 'min',
    'time_hr' => 'tim',
    'time_hrs' => 'timmar',
    'clear' => 'Rensa',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Uppgifts taxa',
    'task_rate_help' => 'Sätt standard debiteringen för fakturerade uppgifter.',
    'past_due' => 'Förfallen',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Faktura/Utgift',
    'invoice_pdfs' => 'Faktura PDFer',
    'enable_sepa' => 'Acceptera SEPA',
    'enable_bitcoin' => 'Acceptera Bitcoin ',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Återskapa licens',
    'purchase' => 'Köp',
    'recover' => 'Återskapa',
    'apply' => 'Verkställ',
    'recover_white_label_header' => 'Återskapa White Label licens',
    'apply_white_label_header' => 'Aktivera White Label licens',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Återgå till faktura',
    'gateway_help_13' => 'För att använda ITN lämna PDT nyckel fältet blankt.',
    'partial_due_date' => 'Delvis förfallen',
    'task_fields' => 'Uppgifts fält',
    'product_fields_help' => 'Drag och släpp fält för att ändra deras ordning',
    'custom_value1' => 'Anpassat värde',
    'custom_value2' => 'Anpassat värde',
    'enable_two_factor' => 'Tvåfaktorsautentisering',
    'enable_two_factor_help' => 'Använd din telefon för att bekräfta identitet vid inlogg',
    'two_factor_setup' => 'Tvåfaktor inställning',
    'two_factor_setup_help' => 'Skanna streckkoden med en :link kompatibel app.',
    'one_time_password' => 'Engångs lösenord',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Aktiverade Två-Vägs autentisering utan problem',
    'add_product' => 'Lägg till produkt',
    'email_will_be_sent_on' => 'Notis: e-posten kommer skickad den :date',
    'invoice_product' => 'Fakturera produkt',
    'self_host_login' => 'Self-Host Inlogg',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Fel: lokal lagring är inte tillgänglig.',
    'your_password_reset_link' => 'Din lösenordsåterställnings länk',
    'subdomain_taken' => 'Subdomänen är upptagen',
    'client_login' => 'Kund inlogg',
    'converted_amount' => 'Konverterad summa',
    'default' => 'Standard',
    'shipping_address' => 'Leverans adress',
    'bllling_address' => 'Fakturerings adress',
    'billing_address1' => 'Fakturerings gata',
    'billing_address2' => 'Fakturerings våning',
    'billing_city' => 'Fakturerings stad',
    'billing_state' => 'Fakturerings län',
    'billing_postal_code' => 'Fakturerings postnummer',
    'billing_country' => 'Fakturerings land',
    'shipping_address1' => 'Leverans gata',
    'shipping_address2' => 'Leverans våning',
    'shipping_city' => 'Leverans stad',
    'shipping_state' => 'Leverans län',
    'shipping_postal_code' => 'Leverans postnummer',
    'shipping_country' => 'Leverans land',
    'classify' => 'Klassificera ',
    'show_shipping_address_help' => 'Kräv att kunden skriver sin leveransadress',
    'ship_to_billing_address' => 'Skicka till fakturaadress',
    'delivery_note' => 'Följesedel',
    'show_tasks_in_portal' => 'Visa uppgifter i kund portalen',
    'cancel_schedule' => 'Avbryt schema',
    'scheduled_report' => 'Schemalagd rapport',
    'scheduled_report_help' => 'Eposta :report rapporten som :format till :email',
    'created_scheduled_report' => 'Schemalagt rapporten utan problem',
    'deleted_scheduled_report' => 'Avbrutit den schemalagda rapporten utan problem',
    'scheduled_report_attached' => 'Din schemalagda :type rapport är bifogad.',
    'scheduled_report_error' => 'Misslyckades med att skapa schemalagd rapport',
    'invalid_one_time_password' => 'Ogiltigt engångs lösen',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Acceptera Apple Pay och Betala med Google',
    'requires_subdomain' => 'Denna betalningstyp kräver att en :link.',
    'subdomain_is_set' => 'subdomän är vald',
    'verification_file' => 'Verifikations fil',
    'verification_file_missing' => 'Verifikationsfilen behövs för att acceptera betalningar.',
    'apple_pay_domain' => 'Använd <code>:domain</code> som domän i :link.',
    'apple_pay_not_supported' => 'Tyvärr, Apple/Google Pay är inte supportat i din webbläsare ',
    'optional_payment_methods' => 'Alternativa betalningssätt',
    'add_subscription' => 'Lägg till prenumeration',
    'target_url' => 'Mål',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Händelse',
    'subscription_event_1' => 'Skapat kund',
    'subscription_event_2' => 'Skapat faktura',
    'subscription_event_3' => 'Skapat offert',
    'subscription_event_4' => 'Skapat betalning',
    'subscription_event_5' => 'Skapat tillverkare',
    'subscription_event_6' => 'Uppdaterat offert',
    'subscription_event_7' => 'Tagit bort offert',
    'subscription_event_8' => 'Uppdaterat faktura',
    'subscription_event_9' => 'Tagit bort faktura',
    'subscription_event_10' => 'Uppdaterat kund',
    'subscription_event_11' => 'Tagit bort kund',
    'subscription_event_12' => 'Tagit bort betalning',
    'subscription_event_13' => 'Uppdaterat tillverkare',
    'subscription_event_14' => 'Tagit bort tillverkare',
    'subscription_event_15' => 'Skapat utgift',
    'subscription_event_16' => 'Uppdaterat utgift ',
    'subscription_event_17' => 'Tagit bort utgift',
    'subscription_event_18' => 'Skapat uppgift',
    'subscription_event_19' => 'Uppdaterat uppgift',
    'subscription_event_20' => 'Tagit bort uppgift',
    'subscription_event_21' => 'Godkänt offert',
    'subscriptions' => 'Prenumerationer',
    'updated_subscription' => 'Uppdaterat prenumerationer utan problem',
    'created_subscription' => 'Skapat prenumerationer utan problem',
    'edit_subscription' => 'Ändra prenumeration',
    'archive_subscription' => 'Arkivera prenumeration',
    'archived_subscription' => 'Arkivera prenumeration utan problem',
    'project_error_multiple_clients' => 'Projektet kan inte tillhöra olika kunder',
    'invoice_project' => 'Fakturera projekt',
    'module_recurring_invoice' => 'Återkommande fakturor',
    'module_credit' => 'Krediter',
    'module_quote' => 'Offerter & Förslag',
    'module_task' => 'Uppgifter & Projekt',
    'module_expense' => 'Utgifter & Tillverkare',
    'module_ticket' => 'Tickets',
    'reminders' => 'Påminnelser',
    'send_client_reminders' => 'Skicka e-post påminnelser',
    'can_view_tasks' => 'Uppgifter är synliga i portalen',
    'is_not_sent_reminders' => 'Påminnelser är inte skickade',
    'promotion_footer' => 'Ditt erbjudande löper snart ut, :link för att uppgradera nu.',
    'unable_to_delete_primary' => 'Notis: för att ta bort detta bolaget ta först bort alla länkade bolag.',
    'please_register' => 'Vänligen registrera ditt konto',
    'processing_request' => 'Arbetar med förfrågning',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Ändra tider',
    'inclusive_taxes_help' => 'Inkludera <b>moms i kostnaden</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Kopiera frakt',
    'copy_billing' => 'Kopiera betalning',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Visar 0 till 0 av 0 poster',
    'do_not_trust' => 'Kom inte ihåg denna enheten',
    'trust_for_30_days' => 'Kom ihåg i 30 dagar',
    'trust_forever' => 'Kom ihåg för alltid',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Klart att arbeta med',
    'in_progress' => 'Under behandling',
    'add_status' => 'Lägg till status',
    'archive_status' => 'Arkivera status',
    'new_status' => 'Ny status',
    'convert_products' => 'Konvertera produkter',
    'convert_products_help' => 'Konvertera automatiskt produkt priser till kundens valuta ',
    'improve_client_portal_link' => 'Sätt en subdomän för att korta ner kund portals länken.',
    'budgeted_hours' => 'Budgeterade timmar',
    'progress' => 'Utveckling',
    'view_project' => 'Se projekt',
    'summary' => 'Summering',
    'endless_reminder' => 'Oändlig påminnelse',
    'signature_on_invoice_help' => 'Lägg till följande kod för att visa din kunds signatur på PDF´n.',
    'signature_on_pdf' => 'Visa på PDF',
    'signature_on_pdf_help' => 'Visa kundens signatur på fakturan/offerten.',
    'expired_white_label' => 'White label licensen har gått ut',
    'return_to_login' => 'Återgå till inlogg',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Använd <code>Label|Option1,Option2</code> för att visa vald box.',
    'client_information' => 'Kund information',
    'updated_client_details' => 'Uppdaterade kund detaljer utan problem',
    'auto' => 'Auto',
    'tax_amount' => 'Moms summa',
    'tax_paid' => 'Moms betalad',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Förslag',
    'proposals' => 'Förslag',
    'list_proposals' => 'Lista förslag',
    'new_proposal' => 'New Proposal',
    'edit_proposal' => 'Edit Proposal',
    'archive_proposal' => 'Archive Proposal',
    'delete_proposal' => 'Delete Proposal',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Arkivering av :count förslag har lyckats',
    'deleted_proposals' => 'Arkivering av :count förslag har lyckats',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Mall',
    'templates' => 'Mallar',
    'proposal_template' => 'Mall',
    'proposal_templates' => 'Mallar',
    'new_proposal_template' => 'Ny mall',
    'edit_proposal_template' => 'Ändra mall',
    'archive_proposal_template' => 'Arkivera mall',
    'delete_proposal_template' => 'Ta bort mall',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Återställ mall',
    'proposal_category' => 'Kategori',
    'proposal_categories' => 'Kategorier',
    'new_proposal_category' => 'Ny kategori',
    'edit_proposal_category' => 'Ändra kategori',
    'archive_proposal_category' => 'Arkivera kategori',
    'delete_proposal_category' => 'Ta bort kategori',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Återställ kategori',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Ikon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Skapa kategori',
    'clone_proposal_template' => 'Kopiera mall',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Lägg till bild',
    'select_image' => 'Välj bild',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Ta bort bild',
    'delete_image_help' => 'Warning: Bortagning av denna bild kommer ta bort den från alla förslag',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'E-postadress har ändrats',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exportering till ZIP kräver GMP-tillägget',
    'email_history' => 'E-posthistorik',
    'loading' => 'Laddar',
    'no_messages_found' => 'No messages found',
    'processing' => 'Bearbetar',
    'reactivate' => 'Återaktivera',
    'reactivated_email' => 'E-postadressen har återaktiverats',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Klona produkt',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'Se offert',
    'view_in_portal' => 'Se i portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Importera leverantörer',
    'company' => 'Företag',
    'client_field' => 'Klientfält',
    'contact_field' => 'Kontaktfält',
    'product_field' => 'Produktfält',
    'task_field' => 'Uppgiftsfält',
    'project_field' => 'Projektfält',
    'expense_field' => 'Utgiftsfält',
    'vendor_field' => 'Leverantörsfält',
    'company_field' => 'Företagsfält',
    'invoice_field' => 'Fakturafält',
    'invoice_surcharge' => 'Tilläggsavgift till faktura',
    'custom_task_fields_help' => 'Lägg till ett fält när en uppgift skapas.',
    'custom_project_fields_help' => 'Lägg till ett fält när ett projekt skapas.',
    'custom_expense_fields_help' => 'Lägg till ett fält när en utgift skapas.',
    'custom_vendor_fields_help' => 'Lägg till ett fält när en leverantör skapas.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Visa betalningar',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'Alla fakturor',
    'my_invoices' => 'Mina fakturor',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'För att ladda upp en bakgrundsbild :link för att aktivera förslag modulen',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
